// This file is generated by KDAB's kdwsdl2cpp from wsdd-discovery-1.1-wsdl-os.wsdl.
// All changes you do to this file will be lost.
/*
    You may use and relicense this generated file without restriction.
*/
#pragma once

#include <KDSoapClient/KDSoapValue.h>
#include <QtCore/QList>
#include <QSharedPointer>
#include <QtCore/QSharedData>
#include <KDSoapClient/KDQName.h>
#include <QtCore/QStringList>
#include <QtCore/QString>

#undef daylight
#undef timezone
namespace WSDiscovery200901 {
    class TNS__ProbeMatchType;
    class TNS__QNameListType;
    class TNS__ResolveMatchType;
    class TNS__ScopesType;
    class TNS__UriListType;
    class WSA__AttributedURIType;
    class WSA__EndpointReferenceType;
    class WSA__MetadataType;
    class WSA__ReferenceParametersType;
}


namespace WSDiscovery200901 {
    class TNS__ByeType
    {
    public:
        void setEndpointReference( const WSDiscovery200901::WSA__EndpointReferenceType& arg_endpointReference );
        WSDiscovery200901::WSA__EndpointReferenceType endpointReference() const;
        void setTypes( const WSDiscovery200901::TNS__QNameListType& arg_types );
        WSDiscovery200901::TNS__QNameListType types() const;
        bool hasValueForTypes() const;
        void setScopes( const WSDiscovery200901::TNS__ScopesType& arg_scopes );
        WSDiscovery200901::TNS__ScopesType scopes() const;
        bool hasValueForScopes() const;
        void setXAddrs( const WSDiscovery200901::TNS__UriListType& arg_xAddrs );
        WSDiscovery200901::TNS__UriListType xAddrs() const;
        bool hasValueForXAddrs() const;
        void setMetadataVersion( unsigned int arg_metadataVersion );
        unsigned int metadataVersion() const;
        bool hasValueForMetadataVersion() const;
        void setAny( const QList< KDSoapValue >& arg_any );
        QList< KDSoapValue > any() const;
        bool hasValueForAny() const;
        void setAnyAttribute( const KDSoapValue& arg_anyAttribute );
        KDSoapValue anyAttribute() const;
        bool hasValueForAnyAttribute() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        TNS__ByeType();
        ~TNS__ByeType();

    public:
        TNS__ByeType( const TNS__ByeType& );
        TNS__ByeType &operator=( const TNS__ByeType& );

    private:
        class PrivateDPtr;
        QSharedDataPointer<PrivateDPtr> d_ptr;
    };
} // namespace end

namespace WSDiscovery200901 {
    class TNS__HelloType
    {
    public:
        void setEndpointReference( const WSDiscovery200901::WSA__EndpointReferenceType& arg_endpointReference );
        WSDiscovery200901::WSA__EndpointReferenceType endpointReference() const;
        void setTypes( const WSDiscovery200901::TNS__QNameListType& arg_types );
        WSDiscovery200901::TNS__QNameListType types() const;
        bool hasValueForTypes() const;
        void setScopes( const WSDiscovery200901::TNS__ScopesType& arg_scopes );
        WSDiscovery200901::TNS__ScopesType scopes() const;
        bool hasValueForScopes() const;
        void setXAddrs( const WSDiscovery200901::TNS__UriListType& arg_xAddrs );
        WSDiscovery200901::TNS__UriListType xAddrs() const;
        bool hasValueForXAddrs() const;
        void setMetadataVersion( unsigned int arg_metadataVersion );
        unsigned int metadataVersion() const;
        void setAny( const QList< KDSoapValue >& arg_any );
        QList< KDSoapValue > any() const;
        bool hasValueForAny() const;
        void setAnyAttribute( const KDSoapValue& arg_anyAttribute );
        KDSoapValue anyAttribute() const;
        bool hasValueForAnyAttribute() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        TNS__HelloType();
        ~TNS__HelloType();

    public:
        TNS__HelloType( const TNS__HelloType& );
        TNS__HelloType &operator=( const TNS__HelloType& );

    private:
        class PrivateDPtr;
        QSharedDataPointer<PrivateDPtr> d_ptr;
    };
} // namespace end

namespace WSDiscovery200901 {
    class TNS__ProbeMatchType
    {
    public:
        void setEndpointReference( const WSDiscovery200901::WSA__EndpointReferenceType& arg_endpointReference );
        WSDiscovery200901::WSA__EndpointReferenceType endpointReference() const;
        void setTypes( const WSDiscovery200901::TNS__QNameListType& arg_types );
        WSDiscovery200901::TNS__QNameListType types() const;
        bool hasValueForTypes() const;
        void setScopes( const WSDiscovery200901::TNS__ScopesType& arg_scopes );
        WSDiscovery200901::TNS__ScopesType scopes() const;
        bool hasValueForScopes() const;
        void setXAddrs( const WSDiscovery200901::TNS__UriListType& arg_xAddrs );
        WSDiscovery200901::TNS__UriListType xAddrs() const;
        bool hasValueForXAddrs() const;
        void setMetadataVersion( unsigned int arg_metadataVersion );
        unsigned int metadataVersion() const;
        void setAny( const QList< KDSoapValue >& arg_any );
        QList< KDSoapValue > any() const;
        bool hasValueForAny() const;
        void setAnyAttribute( const KDSoapValue& arg_anyAttribute );
        KDSoapValue anyAttribute() const;
        bool hasValueForAnyAttribute() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        TNS__ProbeMatchType();
        ~TNS__ProbeMatchType();

    public:
        TNS__ProbeMatchType( const TNS__ProbeMatchType& );
        TNS__ProbeMatchType &operator=( const TNS__ProbeMatchType& );

    private:
        class PrivateDPtr;
        QSharedDataPointer<PrivateDPtr> d_ptr;
    };
} // namespace end

namespace WSDiscovery200901 {
    class TNS__ProbeMatchesType
    {
    public:
        void setProbeMatch( const QList< WSDiscovery200901::TNS__ProbeMatchType >& arg_probeMatch );
        QList< WSDiscovery200901::TNS__ProbeMatchType > probeMatch() const;
        bool hasValueForProbeMatch() const;
        void setAny( const QList< KDSoapValue >& arg_any );
        QList< KDSoapValue > any() const;
        bool hasValueForAny() const;
        void setAnyAttribute( const KDSoapValue& arg_anyAttribute );
        KDSoapValue anyAttribute() const;
        bool hasValueForAnyAttribute() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        TNS__ProbeMatchesType();
        ~TNS__ProbeMatchesType();

    public:
        TNS__ProbeMatchesType( const TNS__ProbeMatchesType& );
        TNS__ProbeMatchesType &operator=( const TNS__ProbeMatchesType& );

    private:
        class PrivateDPtr;
        QSharedDataPointer<PrivateDPtr> d_ptr;
    };
} // namespace end

namespace WSDiscovery200901 {
    class TNS__ProbeType
    {
    public:
        void setTypes( const WSDiscovery200901::TNS__QNameListType& arg_types );
        WSDiscovery200901::TNS__QNameListType types() const;
        bool hasValueForTypes() const;
        void setScopes( const WSDiscovery200901::TNS__ScopesType& arg_scopes );
        WSDiscovery200901::TNS__ScopesType scopes() const;
        bool hasValueForScopes() const;
        void setAny( const QList< KDSoapValue >& arg_any );
        QList< KDSoapValue > any() const;
        bool hasValueForAny() const;
        void setAnyAttribute( const KDSoapValue& arg_anyAttribute );
        KDSoapValue anyAttribute() const;
        bool hasValueForAnyAttribute() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        TNS__ProbeType();
        ~TNS__ProbeType();

    public:
        TNS__ProbeType( const TNS__ProbeType& );
        TNS__ProbeType &operator=( const TNS__ProbeType& );

    private:
        class PrivateDPtr;
        QSharedDataPointer<PrivateDPtr> d_ptr;
    };
} // namespace end

namespace WSDiscovery200901 {
    /**
        This class encapsulates a list type.
     */
    class TNS__QNameListType
    {
    public:
        void setEntries( const QList< KDQName >& entries );
        QList< KDQName > entries() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        TNS__QNameListType();
        ~TNS__QNameListType();

    private:
        QList< KDQName > mEntries;
    };
} // namespace end

namespace WSDiscovery200901 {
    class TNS__ResolveMatchType
    {
    public:
        void setEndpointReference( const WSDiscovery200901::WSA__EndpointReferenceType& arg_endpointReference );
        WSDiscovery200901::WSA__EndpointReferenceType endpointReference() const;
        void setTypes( const WSDiscovery200901::TNS__QNameListType& arg_types );
        WSDiscovery200901::TNS__QNameListType types() const;
        bool hasValueForTypes() const;
        void setScopes( const WSDiscovery200901::TNS__ScopesType& arg_scopes );
        WSDiscovery200901::TNS__ScopesType scopes() const;
        bool hasValueForScopes() const;
        void setXAddrs( const WSDiscovery200901::TNS__UriListType& arg_xAddrs );
        WSDiscovery200901::TNS__UriListType xAddrs() const;
        bool hasValueForXAddrs() const;
        void setMetadataVersion( unsigned int arg_metadataVersion );
        unsigned int metadataVersion() const;
        void setAny( const QList< KDSoapValue >& arg_any );
        QList< KDSoapValue > any() const;
        bool hasValueForAny() const;
        void setAnyAttribute( const KDSoapValue& arg_anyAttribute );
        KDSoapValue anyAttribute() const;
        bool hasValueForAnyAttribute() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        TNS__ResolveMatchType();
        ~TNS__ResolveMatchType();

    public:
        TNS__ResolveMatchType( const TNS__ResolveMatchType& );
        TNS__ResolveMatchType &operator=( const TNS__ResolveMatchType& );

    private:
        class PrivateDPtr;
        QSharedDataPointer<PrivateDPtr> d_ptr;
    };
} // namespace end

namespace WSDiscovery200901 {
    class TNS__ResolveMatchesType
    {
    public:
        void setResolveMatch( const WSDiscovery200901::TNS__ResolveMatchType& arg_resolveMatch );
        WSDiscovery200901::TNS__ResolveMatchType resolveMatch() const;
        bool hasValueForResolveMatch() const;
        void setAny( const QList< KDSoapValue >& arg_any );
        QList< KDSoapValue > any() const;
        bool hasValueForAny() const;
        void setAnyAttribute( const KDSoapValue& arg_anyAttribute );
        KDSoapValue anyAttribute() const;
        bool hasValueForAnyAttribute() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        TNS__ResolveMatchesType();
        ~TNS__ResolveMatchesType();

    public:
        TNS__ResolveMatchesType( const TNS__ResolveMatchesType& );
        TNS__ResolveMatchesType &operator=( const TNS__ResolveMatchesType& );

    private:
        class PrivateDPtr;
        QSharedDataPointer<PrivateDPtr> d_ptr;
    };
} // namespace end

namespace WSDiscovery200901 {
    class TNS__ResolveType
    {
    public:
        void setEndpointReference( const WSDiscovery200901::WSA__EndpointReferenceType& arg_endpointReference );
        WSDiscovery200901::WSA__EndpointReferenceType endpointReference() const;
        void setAny( const QList< KDSoapValue >& arg_any );
        QList< KDSoapValue > any() const;
        bool hasValueForAny() const;
        void setAnyAttribute( const KDSoapValue& arg_anyAttribute );
        KDSoapValue anyAttribute() const;
        bool hasValueForAnyAttribute() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        TNS__ResolveType();
        ~TNS__ResolveType();

    public:
        TNS__ResolveType( const TNS__ResolveType& );
        TNS__ResolveType &operator=( const TNS__ResolveType& );

    private:
        class PrivateDPtr;
        QSharedDataPointer<PrivateDPtr> d_ptr;
    };
} // namespace end

namespace WSDiscovery200901 {
    class TNS__ScopesType
    {
    public:
        void setValue( const WSDiscovery200901::TNS__UriListType& arg_value );
        WSDiscovery200901::TNS__UriListType value() const;
        TNS__ScopesType( const WSDiscovery200901::TNS__UriListType& value );
        operator WSDiscovery200901::TNS__UriListType() const;
        void setMatchBy( const QString& arg_matchBy );
        QString matchBy() const;
        bool hasValueForMatchBy() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        TNS__ScopesType();
        ~TNS__ScopesType();

    public:
        TNS__ScopesType( const TNS__ScopesType& );
        TNS__ScopesType &operator=( const TNS__ScopesType& );

    private:
        class PrivateDPtr;
        QSharedDataPointer<PrivateDPtr> d_ptr;
    };
} // namespace end

namespace WSDiscovery200901 {
    /**
        This class encapsulates a list type.
     */
    class TNS__UriListType
    {
    public:
        void setEntries( const QStringList& entries );
        QStringList entries() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        TNS__UriListType();
        ~TNS__UriListType();

    private:
        QStringList mEntries;
    };
} // namespace end

namespace WSDiscovery200901 {
    class WSA__AttributedURIType
    {
    public:
        void setValue( const QString& arg_value );
        QString value() const;
        WSA__AttributedURIType( const QString& value );
        operator QString() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        WSA__AttributedURIType();
        ~WSA__AttributedURIType();

    public:
        WSA__AttributedURIType( const WSA__AttributedURIType& );
        WSA__AttributedURIType &operator=( const WSA__AttributedURIType& );

    private:
        class PrivateDPtr;
        QSharedDataPointer<PrivateDPtr> d_ptr;
    };
} // namespace end

namespace WSDiscovery200901 {
    class WSA__EndpointReferenceType
    {
    public:
        void setAddress( const WSDiscovery200901::WSA__AttributedURIType& arg_address );
        WSDiscovery200901::WSA__AttributedURIType address() const;
        void setReferenceParameters( const WSDiscovery200901::WSA__ReferenceParametersType& arg_referenceParameters );
        WSDiscovery200901::WSA__ReferenceParametersType referenceParameters() const;
        bool hasValueForReferenceParameters() const;
        void setMetadata( const WSDiscovery200901::WSA__MetadataType& arg_metadata );
        WSDiscovery200901::WSA__MetadataType metadata() const;
        bool hasValueForMetadata() const;
        void setAny( const QList< KDSoapValue >& arg_any );
        QList< KDSoapValue > any() const;
        bool hasValueForAny() const;
        void setAnyAttribute( const KDSoapValue& arg_anyAttribute );
        KDSoapValue anyAttribute() const;
        bool hasValueForAnyAttribute() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        WSA__EndpointReferenceType();
        ~WSA__EndpointReferenceType();

    public:
        WSA__EndpointReferenceType( const WSA__EndpointReferenceType& );
        WSA__EndpointReferenceType &operator=( const WSA__EndpointReferenceType& );

    private:
        class PrivateDPtr;
        QSharedDataPointer<PrivateDPtr> d_ptr;
    };
} // namespace end

namespace WSDiscovery200901 {
    class WSA__MetadataType
    {
    public:
        void setAny( const QList< KDSoapValue >& arg_any );
        QList< KDSoapValue > any() const;
        bool hasValueForAny() const;
        void setAnyAttribute( const KDSoapValue& arg_anyAttribute );
        KDSoapValue anyAttribute() const;
        bool hasValueForAnyAttribute() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        WSA__MetadataType();
        ~WSA__MetadataType();

    public:
        WSA__MetadataType( const WSA__MetadataType& );
        WSA__MetadataType &operator=( const WSA__MetadataType& );

    private:
        class PrivateDPtr;
        QSharedDataPointer<PrivateDPtr> d_ptr;
    };
} // namespace end

namespace WSDiscovery200901 {
    class WSA__ReferenceParametersType
    {
    public:
        void setAny( const QList< KDSoapValue >& arg_any );
        QList< KDSoapValue > any() const;
        bool hasValueForAny() const;
        void setAnyAttribute( const KDSoapValue& arg_anyAttribute );
        KDSoapValue anyAttribute() const;
        bool hasValueForAnyAttribute() const;
        KDSoapValue serialize( const QString& valueName ) const;
        void deserialize( const KDSoapValue& mainValue );
        WSA__ReferenceParametersType();
        ~WSA__ReferenceParametersType();

    public:
        WSA__ReferenceParametersType( const WSA__ReferenceParametersType& );
        WSA__ReferenceParametersType &operator=( const WSA__ReferenceParametersType& );

    private:
        class PrivateDPtr;
        QSharedDataPointer<PrivateDPtr> d_ptr;
    };
} // namespace end

