/****************************************************************************
** Meta object code from reading C++ file 'wsdiscoveryclient.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdsoap-ws-discovery-client-0.4.0/src/wsdiscoveryclient.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wsdiscoveryclient.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17WSDiscoveryClientE_t {};
} // unnamed namespace

template <> constexpr inline auto WSDiscoveryClient::qt_create_metaobjectdata<qt_meta_tag_ZN17WSDiscoveryClientE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WSDiscoveryClient",
        "probeMatchReceived",
        "",
        "WSDiscoveryTargetService",
        "probeMatchService",
        "resolveMatchReceived",
        "start",
        "port",
        "sendProbe",
        "QList<KDQName>",
        "typeList",
        "QList<QUrl>",
        "scopeList",
        "sendResolve",
        "endpointReference",
        "receivedMessage",
        "KDSoapMessage",
        "replyMessage",
        "KDSoapHeaders",
        "replyHeaders",
        "QHostAddress",
        "senderAddress",
        "senderPort"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'probeMatchReceived'
        QtMocHelpers::SignalData<void(const WSDiscoveryTargetService &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'resolveMatchReceived'
        QtMocHelpers::SignalData<void(const WSDiscoveryTargetService &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void(quint16)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 7 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'sendProbe'
        QtMocHelpers::SlotData<void(const QList<KDQName> &, const QList<QUrl> &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'sendResolve'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'receivedMessage'
        QtMocHelpers::SlotData<void(const KDSoapMessage &, const KDSoapHeaders &, const QHostAddress &, quint16)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 }, { QMetaType::UShort, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WSDiscoveryClient, qt_meta_tag_ZN17WSDiscoveryClientE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WSDiscoveryClient::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17WSDiscoveryClientE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17WSDiscoveryClientE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17WSDiscoveryClientE_t>.metaTypes,
    nullptr
} };

void WSDiscoveryClient::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WSDiscoveryClient *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->probeMatchReceived((*reinterpret_cast<std::add_pointer_t<WSDiscoveryTargetService>>(_a[1]))); break;
        case 1: _t->resolveMatchReceived((*reinterpret_cast<std::add_pointer_t<WSDiscoveryTargetService>>(_a[1]))); break;
        case 2: _t->start((*reinterpret_cast<std::add_pointer_t<quint16>>(_a[1]))); break;
        case 3: _t->start(); break;
        case 4: _t->sendProbe((*reinterpret_cast<std::add_pointer_t<QList<KDQName>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2]))); break;
        case 5: _t->sendResolve((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->receivedMessage((*reinterpret_cast<std::add_pointer_t<KDSoapMessage>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KDSoapHeaders>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QHostAddress>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<quint16>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<KDQName> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WSDiscoveryClient::*)(const WSDiscoveryTargetService & )>(_a, &WSDiscoveryClient::probeMatchReceived, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WSDiscoveryClient::*)(const WSDiscoveryTargetService & )>(_a, &WSDiscoveryClient::resolveMatchReceived, 1))
            return;
    }
}

const QMetaObject *WSDiscoveryClient::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WSDiscoveryClient::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17WSDiscoveryClientE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int WSDiscoveryClient::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void WSDiscoveryClient::probeMatchReceived(const WSDiscoveryTargetService & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void WSDiscoveryClient::resolveMatchReceived(const WSDiscoveryTargetService & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
