// This file is generated by KDAB's kdwsdl2cpp from ws-discovery.wsdl.
// All changes you do to this file will be lost.
/*
    You may use and relicense this generated file without restriction.
*/

#include "/build/kdsoap-ws-discovery-client/src/build/src/wsdl_ws-discovery.h"

#include <KDSoapClient/KDSoapNamespaceManager.h>

class WSDiscovery200504::TNS__ByeType::PrivateDPtr : public QSharedData
{
public:
    PrivateDPtr();

public:
    WSDiscovery200504::WSA__EndpointReferenceType mEndpointReference;
    WSDiscovery200504::TNS__QNameListType mTypes;
    bool mTypes_nil;
    WSDiscovery200504::TNS__ScopesType mScopes;
    bool mScopes_nil;
    WSDiscovery200504::TNS__UriListType mXAddrs;
    bool mXAddrs_nil;
    unsigned int mMetadataVersion;
    bool mMetadataVersion_nil;
    QList< KDSoapValue > mAny;
    bool mAny_nil;
    KDSoapValue mAnyAttribute;
    bool mAnyAttribute_nil;
};

WSDiscovery200504::TNS__ByeType::PrivateDPtr::PrivateDPtr()
    : mTypes_nil(true), mScopes_nil(true), mXAddrs_nil(true), mMetadataVersion(0), mMetadataVersion_nil(true), mAny_nil(true), mAnyAttribute_nil(true)
{
}


void WSDiscovery200504::TNS__ByeType::setEndpointReference( const WSDiscovery200504::WSA__EndpointReferenceType& arg_endpointReference )
{
    d_ptr->mEndpointReference = arg_endpointReference;
}

WSDiscovery200504::WSA__EndpointReferenceType WSDiscovery200504::TNS__ByeType::endpointReference() const
{
    return d_ptr->mEndpointReference;
}

void WSDiscovery200504::TNS__ByeType::setTypes( const WSDiscovery200504::TNS__QNameListType& arg_types )
{
    d_ptr->mTypes_nil = false;// converter_complextype.cpp:357
    d_ptr->mTypes = arg_types;
}

WSDiscovery200504::TNS__QNameListType WSDiscovery200504::TNS__ByeType::types() const
{
    return d_ptr->mTypes;
}

bool WSDiscovery200504::TNS__ByeType::hasValueForTypes() const
{
    return d_ptr->mTypes_nil == false;
}

void WSDiscovery200504::TNS__ByeType::setScopes( const WSDiscovery200504::TNS__ScopesType& arg_scopes )
{
    d_ptr->mScopes_nil = false;// converter_complextype.cpp:357
    d_ptr->mScopes = arg_scopes;
}

WSDiscovery200504::TNS__ScopesType WSDiscovery200504::TNS__ByeType::scopes() const
{
    return d_ptr->mScopes;
}

bool WSDiscovery200504::TNS__ByeType::hasValueForScopes() const
{
    return d_ptr->mScopes_nil == false;
}

void WSDiscovery200504::TNS__ByeType::setXAddrs( const WSDiscovery200504::TNS__UriListType& arg_xAddrs )
{
    d_ptr->mXAddrs_nil = false;// converter_complextype.cpp:357
    d_ptr->mXAddrs = arg_xAddrs;
}

WSDiscovery200504::TNS__UriListType WSDiscovery200504::TNS__ByeType::xAddrs() const
{
    return d_ptr->mXAddrs;
}

bool WSDiscovery200504::TNS__ByeType::hasValueForXAddrs() const
{
    return d_ptr->mXAddrs_nil == false;
}

void WSDiscovery200504::TNS__ByeType::setMetadataVersion( unsigned int arg_metadataVersion )
{
    d_ptr->mMetadataVersion_nil = false;// converter_complextype.cpp:357
    d_ptr->mMetadataVersion = arg_metadataVersion;
}

unsigned int WSDiscovery200504::TNS__ByeType::metadataVersion() const
{
    return d_ptr->mMetadataVersion;
}

bool WSDiscovery200504::TNS__ByeType::hasValueForMetadataVersion() const
{
    return d_ptr->mMetadataVersion_nil == false;
}

void WSDiscovery200504::TNS__ByeType::setAny( const QList< KDSoapValue >& arg_any )
{
    d_ptr->mAny_nil = false;// converter_complextype.cpp:357
    d_ptr->mAny = arg_any;
}

QList< KDSoapValue > WSDiscovery200504::TNS__ByeType::any() const
{
    return d_ptr->mAny;
}

bool WSDiscovery200504::TNS__ByeType::hasValueForAny() const
{
    return d_ptr->mAny_nil == false;
}

void WSDiscovery200504::TNS__ByeType::setAnyAttribute( const KDSoapValue& arg_anyAttribute )
{
    d_ptr->mAnyAttribute_nil = false;// converter_complextype.cpp:357
    d_ptr->mAnyAttribute = arg_anyAttribute;
}

KDSoapValue WSDiscovery200504::TNS__ByeType::anyAttribute() const
{
    return d_ptr->mAnyAttribute;
}

bool WSDiscovery200504::TNS__ByeType::hasValueForAnyAttribute() const
{
    return d_ptr->mAnyAttribute_nil == false;
}

KDSoapValue WSDiscovery200504::TNS__ByeType::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue(valueName, QVariant(), QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"), QString::fromLatin1("ByeType"));// converter_complextype.cpp:551
    KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:572
    mainValue.setQualified(true);// converter_complextype.cpp:574
    KDSoapValue _valueEndpointReference(d_ptr->mEndpointReference.serialize(QString::fromLatin1("EndpointReference")));// elementargumentserializer.cpp:112
    _valueEndpointReference.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"));
    _valueEndpointReference.setQualified(true);
    args.append(_valueEndpointReference);// elementargumentserializer.cpp:132
    if (!d_ptr->mTypes_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueTypes = d_ptr->mTypes.serialize(QString::fromLatin1("Types"));// elementargumentserializer.cpp:120
        _valueTypes.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueTypes.setQualified(true);
        args.append(_valueTypes);// elementargumentserializer.cpp:132
    }
    if (!d_ptr->mScopes_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueScopes(d_ptr->mScopes.serialize(QString::fromLatin1("Scopes")));// elementargumentserializer.cpp:112
        _valueScopes.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueScopes.setQualified(true);
        args.append(_valueScopes);// elementargumentserializer.cpp:132
    }
    if (!d_ptr->mXAddrs_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueXAddrs = d_ptr->mXAddrs.serialize(QString::fromLatin1("XAddrs"));// elementargumentserializer.cpp:120
        _valueXAddrs.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueXAddrs.setQualified(true);
        args.append(_valueXAddrs);// elementargumentserializer.cpp:132
    }
    if (!d_ptr->mMetadataVersion_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueMetadataVersion = KDSoapValue(QString::fromLatin1("MetadataVersion"), QVariant::fromValue(d_ptr->mMetadataVersion), KDSoapNamespaceManager::xmlSchema2001(), QString::fromLatin1("unsignedInt"));// elementargumentserializer.cpp:117
        _valueMetadataVersion.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueMetadataVersion.setQualified(true);
        args.append(_valueMetadataVersion);// elementargumentserializer.cpp:132
    }
    for (int i = 0; i < d_ptr->mAny.count(); ++i) {// converter_complextype.cpp:640
        if (!d_ptr->mAny.at(i).isNull()) {
            args.append(d_ptr->mAny.at(i));// elementargumentserializer.cpp:90
        }
    }
    KDSoapValueList attribs;
    if (!d_ptr->mAnyAttribute.isNull()) {
        attribs.append(d_ptr->mAnyAttribute);// elementargumentserializer.cpp:90
    }
    mainValue.childValues().attributes() += attribs;// converter_complextype.cpp:720
    return mainValue;
}

void WSDiscovery200504::TNS__ByeType::deserialize( const KDSoapValue& mainValue )
{
    const KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:568
    for (const KDSoapValue& val : std::as_const(args)) {
        const QString _name = val.name();
        if (_name == QLatin1String("EndpointReference")) {// converter_complextype.cpp:488
            d_ptr->mEndpointReference.deserialize(val);// elementargumentserializer.cpp:216
        }
        else if (_name == QLatin1String("Types")) {// converter_complextype.cpp:488
            d_ptr->mTypes.deserialize(val);// elementargumentserializer.cpp:218
            d_ptr->mTypes_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("Scopes")) {// converter_complextype.cpp:488
            d_ptr->mScopes.deserialize(val);// elementargumentserializer.cpp:216
            d_ptr->mScopes_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("XAddrs")) {// converter_complextype.cpp:488
            d_ptr->mXAddrs.deserialize(val);// elementargumentserializer.cpp:218
            d_ptr->mXAddrs_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("MetadataVersion")) {// converter_complextype.cpp:488
            d_ptr->mMetadataVersion = val.value().value<unsigned int>();// elementargumentserializer.cpp:214
            d_ptr->mMetadataVersion_nil = false;// elementargumentserializer.cpp:221
        }
        else {// converter_complextype.cpp:485
            d_ptr->mAny.append(val);
            d_ptr->mAny_nil = false;// elementargumentserializer.cpp:182
        }
    }
    const QList<KDSoapValue> attribs = args.attributes();
    for (const KDSoapValue& val : std::as_const(attribs)) {
        const QString _name = val.name();
        if (_name == QLatin1String("anyAttribute")) {// converter_complextype.cpp:488
            d_ptr->mAnyAttribute = val;// elementargumentserializer.cpp:210
            d_ptr->mAnyAttribute_nil = false;// elementargumentserializer.cpp:221
        }
    }
}

WSDiscovery200504::TNS__ByeType::TNS__ByeType()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::TNS__ByeType::~TNS__ByeType()
{
}

WSDiscovery200504::TNS__ByeType::TNS__ByeType( const WSDiscovery200504::TNS__ByeType& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::TNS__ByeType&  WSDiscovery200504::TNS__ByeType::operator=( const WSDiscovery200504::TNS__ByeType& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


class WSDiscovery200504::TNS__HelloType::PrivateDPtr : public QSharedData
{
public:
    PrivateDPtr();

public:
    WSDiscovery200504::WSA__EndpointReferenceType mEndpointReference;
    WSDiscovery200504::TNS__QNameListType mTypes;
    bool mTypes_nil;
    WSDiscovery200504::TNS__ScopesType mScopes;
    bool mScopes_nil;
    WSDiscovery200504::TNS__UriListType mXAddrs;
    bool mXAddrs_nil;
    unsigned int mMetadataVersion;
    QList< KDSoapValue > mAny;
    bool mAny_nil;
    KDSoapValue mAnyAttribute;
    bool mAnyAttribute_nil;
};

WSDiscovery200504::TNS__HelloType::PrivateDPtr::PrivateDPtr()
    : mTypes_nil(true), mScopes_nil(true), mXAddrs_nil(true), mMetadataVersion(0), mAny_nil(true), mAnyAttribute_nil(true)
{
}


void WSDiscovery200504::TNS__HelloType::setEndpointReference( const WSDiscovery200504::WSA__EndpointReferenceType& arg_endpointReference )
{
    d_ptr->mEndpointReference = arg_endpointReference;
}

WSDiscovery200504::WSA__EndpointReferenceType WSDiscovery200504::TNS__HelloType::endpointReference() const
{
    return d_ptr->mEndpointReference;
}

void WSDiscovery200504::TNS__HelloType::setTypes( const WSDiscovery200504::TNS__QNameListType& arg_types )
{
    d_ptr->mTypes_nil = false;// converter_complextype.cpp:357
    d_ptr->mTypes = arg_types;
}

WSDiscovery200504::TNS__QNameListType WSDiscovery200504::TNS__HelloType::types() const
{
    return d_ptr->mTypes;
}

bool WSDiscovery200504::TNS__HelloType::hasValueForTypes() const
{
    return d_ptr->mTypes_nil == false;
}

void WSDiscovery200504::TNS__HelloType::setScopes( const WSDiscovery200504::TNS__ScopesType& arg_scopes )
{
    d_ptr->mScopes_nil = false;// converter_complextype.cpp:357
    d_ptr->mScopes = arg_scopes;
}

WSDiscovery200504::TNS__ScopesType WSDiscovery200504::TNS__HelloType::scopes() const
{
    return d_ptr->mScopes;
}

bool WSDiscovery200504::TNS__HelloType::hasValueForScopes() const
{
    return d_ptr->mScopes_nil == false;
}

void WSDiscovery200504::TNS__HelloType::setXAddrs( const WSDiscovery200504::TNS__UriListType& arg_xAddrs )
{
    d_ptr->mXAddrs_nil = false;// converter_complextype.cpp:357
    d_ptr->mXAddrs = arg_xAddrs;
}

WSDiscovery200504::TNS__UriListType WSDiscovery200504::TNS__HelloType::xAddrs() const
{
    return d_ptr->mXAddrs;
}

bool WSDiscovery200504::TNS__HelloType::hasValueForXAddrs() const
{
    return d_ptr->mXAddrs_nil == false;
}

void WSDiscovery200504::TNS__HelloType::setMetadataVersion( unsigned int arg_metadataVersion )
{
    d_ptr->mMetadataVersion = arg_metadataVersion;
}

unsigned int WSDiscovery200504::TNS__HelloType::metadataVersion() const
{
    return d_ptr->mMetadataVersion;
}

void WSDiscovery200504::TNS__HelloType::setAny( const QList< KDSoapValue >& arg_any )
{
    d_ptr->mAny_nil = false;// converter_complextype.cpp:357
    d_ptr->mAny = arg_any;
}

QList< KDSoapValue > WSDiscovery200504::TNS__HelloType::any() const
{
    return d_ptr->mAny;
}

bool WSDiscovery200504::TNS__HelloType::hasValueForAny() const
{
    return d_ptr->mAny_nil == false;
}

void WSDiscovery200504::TNS__HelloType::setAnyAttribute( const KDSoapValue& arg_anyAttribute )
{
    d_ptr->mAnyAttribute_nil = false;// converter_complextype.cpp:357
    d_ptr->mAnyAttribute = arg_anyAttribute;
}

KDSoapValue WSDiscovery200504::TNS__HelloType::anyAttribute() const
{
    return d_ptr->mAnyAttribute;
}

bool WSDiscovery200504::TNS__HelloType::hasValueForAnyAttribute() const
{
    return d_ptr->mAnyAttribute_nil == false;
}

KDSoapValue WSDiscovery200504::TNS__HelloType::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue(valueName, QVariant(), QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"), QString::fromLatin1("HelloType"));// converter_complextype.cpp:551
    KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:572
    mainValue.setQualified(true);// converter_complextype.cpp:574
    KDSoapValue _valueEndpointReference(d_ptr->mEndpointReference.serialize(QString::fromLatin1("EndpointReference")));// elementargumentserializer.cpp:112
    _valueEndpointReference.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"));
    _valueEndpointReference.setQualified(true);
    args.append(_valueEndpointReference);// elementargumentserializer.cpp:132
    if (!d_ptr->mTypes_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueTypes = d_ptr->mTypes.serialize(QString::fromLatin1("Types"));// elementargumentserializer.cpp:120
        _valueTypes.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueTypes.setQualified(true);
        args.append(_valueTypes);// elementargumentserializer.cpp:132
    }
    if (!d_ptr->mScopes_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueScopes(d_ptr->mScopes.serialize(QString::fromLatin1("Scopes")));// elementargumentserializer.cpp:112
        _valueScopes.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueScopes.setQualified(true);
        args.append(_valueScopes);// elementargumentserializer.cpp:132
    }
    if (!d_ptr->mXAddrs_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueXAddrs = d_ptr->mXAddrs.serialize(QString::fromLatin1("XAddrs"));// elementargumentserializer.cpp:120
        _valueXAddrs.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueXAddrs.setQualified(true);
        args.append(_valueXAddrs);// elementargumentserializer.cpp:132
    }
    KDSoapValue _valueMetadataVersion = KDSoapValue(QString::fromLatin1("MetadataVersion"), QVariant::fromValue(d_ptr->mMetadataVersion), KDSoapNamespaceManager::xmlSchema2001(), QString::fromLatin1("unsignedInt"));// elementargumentserializer.cpp:117
    _valueMetadataVersion.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
    _valueMetadataVersion.setQualified(true);
    args.append(_valueMetadataVersion);// elementargumentserializer.cpp:132
    for (int i = 0; i < d_ptr->mAny.count(); ++i) {// converter_complextype.cpp:640
        if (!d_ptr->mAny.at(i).isNull()) {
            args.append(d_ptr->mAny.at(i));// elementargumentserializer.cpp:90
        }
    }
    KDSoapValueList attribs;
    if (!d_ptr->mAnyAttribute.isNull()) {
        attribs.append(d_ptr->mAnyAttribute);// elementargumentserializer.cpp:90
    }
    mainValue.childValues().attributes() += attribs;// converter_complextype.cpp:720
    return mainValue;
}

void WSDiscovery200504::TNS__HelloType::deserialize( const KDSoapValue& mainValue )
{
    const KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:568
    for (const KDSoapValue& val : std::as_const(args)) {
        const QString _name = val.name();
        if (_name == QLatin1String("EndpointReference")) {// converter_complextype.cpp:488
            d_ptr->mEndpointReference.deserialize(val);// elementargumentserializer.cpp:216
        }
        else if (_name == QLatin1String("Types")) {// converter_complextype.cpp:488
            d_ptr->mTypes.deserialize(val);// elementargumentserializer.cpp:218
            d_ptr->mTypes_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("Scopes")) {// converter_complextype.cpp:488
            d_ptr->mScopes.deserialize(val);// elementargumentserializer.cpp:216
            d_ptr->mScopes_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("XAddrs")) {// converter_complextype.cpp:488
            d_ptr->mXAddrs.deserialize(val);// elementargumentserializer.cpp:218
            d_ptr->mXAddrs_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("MetadataVersion")) {// converter_complextype.cpp:488
            d_ptr->mMetadataVersion = val.value().value<unsigned int>();// elementargumentserializer.cpp:214
        }
        else {// converter_complextype.cpp:485
            d_ptr->mAny.append(val);
            d_ptr->mAny_nil = false;// elementargumentserializer.cpp:182
        }
    }
    const QList<KDSoapValue> attribs = args.attributes();
    for (const KDSoapValue& val : std::as_const(attribs)) {
        const QString _name = val.name();
        if (_name == QLatin1String("anyAttribute")) {// converter_complextype.cpp:488
            d_ptr->mAnyAttribute = val;// elementargumentserializer.cpp:210
            d_ptr->mAnyAttribute_nil = false;// elementargumentserializer.cpp:221
        }
    }
}

WSDiscovery200504::TNS__HelloType::TNS__HelloType()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::TNS__HelloType::~TNS__HelloType()
{
}

WSDiscovery200504::TNS__HelloType::TNS__HelloType( const WSDiscovery200504::TNS__HelloType& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::TNS__HelloType&  WSDiscovery200504::TNS__HelloType::operator=( const WSDiscovery200504::TNS__HelloType& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


class WSDiscovery200504::TNS__ProbeMatchType::PrivateDPtr : public QSharedData
{
public:
    PrivateDPtr();

public:
    WSDiscovery200504::WSA__EndpointReferenceType mEndpointReference;
    WSDiscovery200504::TNS__QNameListType mTypes;
    bool mTypes_nil;
    WSDiscovery200504::TNS__ScopesType mScopes;
    bool mScopes_nil;
    WSDiscovery200504::TNS__UriListType mXAddrs;
    bool mXAddrs_nil;
    unsigned int mMetadataVersion;
    QList< KDSoapValue > mAny;
    bool mAny_nil;
    KDSoapValue mAnyAttribute;
    bool mAnyAttribute_nil;
};

WSDiscovery200504::TNS__ProbeMatchType::PrivateDPtr::PrivateDPtr()
    : mTypes_nil(true), mScopes_nil(true), mXAddrs_nil(true), mMetadataVersion(0), mAny_nil(true), mAnyAttribute_nil(true)
{
}


void WSDiscovery200504::TNS__ProbeMatchType::setEndpointReference( const WSDiscovery200504::WSA__EndpointReferenceType& arg_endpointReference )
{
    d_ptr->mEndpointReference = arg_endpointReference;
}

WSDiscovery200504::WSA__EndpointReferenceType WSDiscovery200504::TNS__ProbeMatchType::endpointReference() const
{
    return d_ptr->mEndpointReference;
}

void WSDiscovery200504::TNS__ProbeMatchType::setTypes( const WSDiscovery200504::TNS__QNameListType& arg_types )
{
    d_ptr->mTypes_nil = false;// converter_complextype.cpp:357
    d_ptr->mTypes = arg_types;
}

WSDiscovery200504::TNS__QNameListType WSDiscovery200504::TNS__ProbeMatchType::types() const
{
    return d_ptr->mTypes;
}

bool WSDiscovery200504::TNS__ProbeMatchType::hasValueForTypes() const
{
    return d_ptr->mTypes_nil == false;
}

void WSDiscovery200504::TNS__ProbeMatchType::setScopes( const WSDiscovery200504::TNS__ScopesType& arg_scopes )
{
    d_ptr->mScopes_nil = false;// converter_complextype.cpp:357
    d_ptr->mScopes = arg_scopes;
}

WSDiscovery200504::TNS__ScopesType WSDiscovery200504::TNS__ProbeMatchType::scopes() const
{
    return d_ptr->mScopes;
}

bool WSDiscovery200504::TNS__ProbeMatchType::hasValueForScopes() const
{
    return d_ptr->mScopes_nil == false;
}

void WSDiscovery200504::TNS__ProbeMatchType::setXAddrs( const WSDiscovery200504::TNS__UriListType& arg_xAddrs )
{
    d_ptr->mXAddrs_nil = false;// converter_complextype.cpp:357
    d_ptr->mXAddrs = arg_xAddrs;
}

WSDiscovery200504::TNS__UriListType WSDiscovery200504::TNS__ProbeMatchType::xAddrs() const
{
    return d_ptr->mXAddrs;
}

bool WSDiscovery200504::TNS__ProbeMatchType::hasValueForXAddrs() const
{
    return d_ptr->mXAddrs_nil == false;
}

void WSDiscovery200504::TNS__ProbeMatchType::setMetadataVersion( unsigned int arg_metadataVersion )
{
    d_ptr->mMetadataVersion = arg_metadataVersion;
}

unsigned int WSDiscovery200504::TNS__ProbeMatchType::metadataVersion() const
{
    return d_ptr->mMetadataVersion;
}

void WSDiscovery200504::TNS__ProbeMatchType::setAny( const QList< KDSoapValue >& arg_any )
{
    d_ptr->mAny_nil = false;// converter_complextype.cpp:357
    d_ptr->mAny = arg_any;
}

QList< KDSoapValue > WSDiscovery200504::TNS__ProbeMatchType::any() const
{
    return d_ptr->mAny;
}

bool WSDiscovery200504::TNS__ProbeMatchType::hasValueForAny() const
{
    return d_ptr->mAny_nil == false;
}

void WSDiscovery200504::TNS__ProbeMatchType::setAnyAttribute( const KDSoapValue& arg_anyAttribute )
{
    d_ptr->mAnyAttribute_nil = false;// converter_complextype.cpp:357
    d_ptr->mAnyAttribute = arg_anyAttribute;
}

KDSoapValue WSDiscovery200504::TNS__ProbeMatchType::anyAttribute() const
{
    return d_ptr->mAnyAttribute;
}

bool WSDiscovery200504::TNS__ProbeMatchType::hasValueForAnyAttribute() const
{
    return d_ptr->mAnyAttribute_nil == false;
}

KDSoapValue WSDiscovery200504::TNS__ProbeMatchType::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue(valueName, QVariant(), QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"), QString::fromLatin1("ProbeMatchType"));// converter_complextype.cpp:551
    KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:572
    mainValue.setQualified(true);// converter_complextype.cpp:574
    KDSoapValue _valueEndpointReference(d_ptr->mEndpointReference.serialize(QString::fromLatin1("EndpointReference")));// elementargumentserializer.cpp:112
    _valueEndpointReference.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"));
    _valueEndpointReference.setQualified(true);
    args.append(_valueEndpointReference);// elementargumentserializer.cpp:132
    if (!d_ptr->mTypes_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueTypes = d_ptr->mTypes.serialize(QString::fromLatin1("Types"));// elementargumentserializer.cpp:120
        _valueTypes.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueTypes.setQualified(true);
        args.append(_valueTypes);// elementargumentserializer.cpp:132
    }
    if (!d_ptr->mScopes_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueScopes(d_ptr->mScopes.serialize(QString::fromLatin1("Scopes")));// elementargumentserializer.cpp:112
        _valueScopes.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueScopes.setQualified(true);
        args.append(_valueScopes);// elementargumentserializer.cpp:132
    }
    if (!d_ptr->mXAddrs_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueXAddrs = d_ptr->mXAddrs.serialize(QString::fromLatin1("XAddrs"));// elementargumentserializer.cpp:120
        _valueXAddrs.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueXAddrs.setQualified(true);
        args.append(_valueXAddrs);// elementargumentserializer.cpp:132
    }
    KDSoapValue _valueMetadataVersion = KDSoapValue(QString::fromLatin1("MetadataVersion"), QVariant::fromValue(d_ptr->mMetadataVersion), KDSoapNamespaceManager::xmlSchema2001(), QString::fromLatin1("unsignedInt"));// elementargumentserializer.cpp:117
    _valueMetadataVersion.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
    _valueMetadataVersion.setQualified(true);
    args.append(_valueMetadataVersion);// elementargumentserializer.cpp:132
    for (int i = 0; i < d_ptr->mAny.count(); ++i) {// converter_complextype.cpp:640
        if (!d_ptr->mAny.at(i).isNull()) {
            args.append(d_ptr->mAny.at(i));// elementargumentserializer.cpp:90
        }
    }
    KDSoapValueList attribs;
    if (!d_ptr->mAnyAttribute.isNull()) {
        attribs.append(d_ptr->mAnyAttribute);// elementargumentserializer.cpp:90
    }
    mainValue.childValues().attributes() += attribs;// converter_complextype.cpp:720
    return mainValue;
}

void WSDiscovery200504::TNS__ProbeMatchType::deserialize( const KDSoapValue& mainValue )
{
    const KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:568
    for (const KDSoapValue& val : std::as_const(args)) {
        const QString _name = val.name();
        if (_name == QLatin1String("EndpointReference")) {// converter_complextype.cpp:488
            d_ptr->mEndpointReference.deserialize(val);// elementargumentserializer.cpp:216
        }
        else if (_name == QLatin1String("Types")) {// converter_complextype.cpp:488
            d_ptr->mTypes.deserialize(val);// elementargumentserializer.cpp:218
            d_ptr->mTypes_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("Scopes")) {// converter_complextype.cpp:488
            d_ptr->mScopes.deserialize(val);// elementargumentserializer.cpp:216
            d_ptr->mScopes_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("XAddrs")) {// converter_complextype.cpp:488
            d_ptr->mXAddrs.deserialize(val);// elementargumentserializer.cpp:218
            d_ptr->mXAddrs_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("MetadataVersion")) {// converter_complextype.cpp:488
            d_ptr->mMetadataVersion = val.value().value<unsigned int>();// elementargumentserializer.cpp:214
        }
        else {// converter_complextype.cpp:485
            d_ptr->mAny.append(val);
            d_ptr->mAny_nil = false;// elementargumentserializer.cpp:182
        }
    }
    const QList<KDSoapValue> attribs = args.attributes();
    for (const KDSoapValue& val : std::as_const(attribs)) {
        const QString _name = val.name();
        if (_name == QLatin1String("anyAttribute")) {// converter_complextype.cpp:488
            d_ptr->mAnyAttribute = val;// elementargumentserializer.cpp:210
            d_ptr->mAnyAttribute_nil = false;// elementargumentserializer.cpp:221
        }
    }
}

WSDiscovery200504::TNS__ProbeMatchType::TNS__ProbeMatchType()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::TNS__ProbeMatchType::~TNS__ProbeMatchType()
{
}

WSDiscovery200504::TNS__ProbeMatchType::TNS__ProbeMatchType( const WSDiscovery200504::TNS__ProbeMatchType& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::TNS__ProbeMatchType&  WSDiscovery200504::TNS__ProbeMatchType::operator=( const WSDiscovery200504::TNS__ProbeMatchType& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


class WSDiscovery200504::TNS__ProbeMatchesType::PrivateDPtr : public QSharedData
{
public:
    PrivateDPtr();

public:
    QList< WSDiscovery200504::TNS__ProbeMatchType > mProbeMatch;
    bool mProbeMatch_nil;
    QList< KDSoapValue > mAny;
    bool mAny_nil;
    KDSoapValue mAnyAttribute;
    bool mAnyAttribute_nil;
};

WSDiscovery200504::TNS__ProbeMatchesType::PrivateDPtr::PrivateDPtr()
    : mProbeMatch_nil(true), mAny_nil(true), mAnyAttribute_nil(true)
{
}


void WSDiscovery200504::TNS__ProbeMatchesType::setProbeMatch( const QList< WSDiscovery200504::TNS__ProbeMatchType >& arg_probeMatch )
{
    d_ptr->mProbeMatch_nil = false;// converter_complextype.cpp:357
    d_ptr->mProbeMatch = arg_probeMatch;
}

QList< WSDiscovery200504::TNS__ProbeMatchType > WSDiscovery200504::TNS__ProbeMatchesType::probeMatch() const
{
    return d_ptr->mProbeMatch;
}

bool WSDiscovery200504::TNS__ProbeMatchesType::hasValueForProbeMatch() const
{
    return d_ptr->mProbeMatch_nil == false;
}

void WSDiscovery200504::TNS__ProbeMatchesType::setAny( const QList< KDSoapValue >& arg_any )
{
    d_ptr->mAny_nil = false;// converter_complextype.cpp:357
    d_ptr->mAny = arg_any;
}

QList< KDSoapValue > WSDiscovery200504::TNS__ProbeMatchesType::any() const
{
    return d_ptr->mAny;
}

bool WSDiscovery200504::TNS__ProbeMatchesType::hasValueForAny() const
{
    return d_ptr->mAny_nil == false;
}

void WSDiscovery200504::TNS__ProbeMatchesType::setAnyAttribute( const KDSoapValue& arg_anyAttribute )
{
    d_ptr->mAnyAttribute_nil = false;// converter_complextype.cpp:357
    d_ptr->mAnyAttribute = arg_anyAttribute;
}

KDSoapValue WSDiscovery200504::TNS__ProbeMatchesType::anyAttribute() const
{
    return d_ptr->mAnyAttribute;
}

bool WSDiscovery200504::TNS__ProbeMatchesType::hasValueForAnyAttribute() const
{
    return d_ptr->mAnyAttribute_nil == false;
}

KDSoapValue WSDiscovery200504::TNS__ProbeMatchesType::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue(valueName, QVariant(), QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"), QString::fromLatin1("ProbeMatchesType"));// converter_complextype.cpp:551
    KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:572
    mainValue.setQualified(true);// converter_complextype.cpp:574
    for (int i = 0; i < d_ptr->mProbeMatch.count(); ++i) {// converter_complextype.cpp:640
        KDSoapValue _valueProbeMatch(d_ptr->mProbeMatch.at(i).serialize(QString::fromLatin1("ProbeMatch")));// elementargumentserializer.cpp:112
        _valueProbeMatch.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueProbeMatch.setQualified(true);
        args.append(_valueProbeMatch);// elementargumentserializer.cpp:132
    }
    for (int i = 0; i < d_ptr->mAny.count(); ++i) {// converter_complextype.cpp:640
        if (!d_ptr->mAny.at(i).isNull()) {
            args.append(d_ptr->mAny.at(i));// elementargumentserializer.cpp:90
        }
    }
    KDSoapValueList attribs;
    if (!d_ptr->mAnyAttribute.isNull()) {
        attribs.append(d_ptr->mAnyAttribute);// elementargumentserializer.cpp:90
    }
    mainValue.childValues().attributes() += attribs;// converter_complextype.cpp:720
    return mainValue;
}

void WSDiscovery200504::TNS__ProbeMatchesType::deserialize( const KDSoapValue& mainValue )
{
    const KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:568
    for (const KDSoapValue& val : std::as_const(args)) {
        const QString _name = val.name();
        if (_name == QLatin1String("ProbeMatch")) {// converter_complextype.cpp:488
            WSDiscovery200504::TNS__ProbeMatchType mProbeMatchTemp;// elementargumentserializer.cpp:170
            mProbeMatchTemp.deserialize(val);// elementargumentserializer.cpp:216
            d_ptr->mProbeMatch.append(mProbeMatchTemp);// elementargumentserializer.cpp:179
            d_ptr->mProbeMatch_nil = false;// elementargumentserializer.cpp:182
        }
        else {// converter_complextype.cpp:485
            d_ptr->mAny.append(val);
            d_ptr->mAny_nil = false;// elementargumentserializer.cpp:182
        }
    }
    const QList<KDSoapValue> attribs = args.attributes();
    for (const KDSoapValue& val : std::as_const(attribs)) {
        const QString _name = val.name();
        if (_name == QLatin1String("anyAttribute")) {// converter_complextype.cpp:488
            d_ptr->mAnyAttribute = val;// elementargumentserializer.cpp:210
            d_ptr->mAnyAttribute_nil = false;// elementargumentserializer.cpp:221
        }
    }
}

WSDiscovery200504::TNS__ProbeMatchesType::TNS__ProbeMatchesType()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::TNS__ProbeMatchesType::~TNS__ProbeMatchesType()
{
}

WSDiscovery200504::TNS__ProbeMatchesType::TNS__ProbeMatchesType( const WSDiscovery200504::TNS__ProbeMatchesType& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::TNS__ProbeMatchesType&  WSDiscovery200504::TNS__ProbeMatchesType::operator=( const WSDiscovery200504::TNS__ProbeMatchesType& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


class WSDiscovery200504::TNS__ProbeType::PrivateDPtr : public QSharedData
{
public:
    PrivateDPtr();

public:
    WSDiscovery200504::TNS__QNameListType mTypes;
    bool mTypes_nil;
    WSDiscovery200504::TNS__ScopesType mScopes;
    bool mScopes_nil;
    QList< KDSoapValue > mAny;
    bool mAny_nil;
    KDSoapValue mAnyAttribute;
    bool mAnyAttribute_nil;
};

WSDiscovery200504::TNS__ProbeType::PrivateDPtr::PrivateDPtr()
    : mTypes_nil(true), mScopes_nil(true), mAny_nil(true), mAnyAttribute_nil(true)
{
}


void WSDiscovery200504::TNS__ProbeType::setTypes( const WSDiscovery200504::TNS__QNameListType& arg_types )
{
    d_ptr->mTypes_nil = false;// converter_complextype.cpp:357
    d_ptr->mTypes = arg_types;
}

WSDiscovery200504::TNS__QNameListType WSDiscovery200504::TNS__ProbeType::types() const
{
    return d_ptr->mTypes;
}

bool WSDiscovery200504::TNS__ProbeType::hasValueForTypes() const
{
    return d_ptr->mTypes_nil == false;
}

void WSDiscovery200504::TNS__ProbeType::setScopes( const WSDiscovery200504::TNS__ScopesType& arg_scopes )
{
    d_ptr->mScopes_nil = false;// converter_complextype.cpp:357
    d_ptr->mScopes = arg_scopes;
}

WSDiscovery200504::TNS__ScopesType WSDiscovery200504::TNS__ProbeType::scopes() const
{
    return d_ptr->mScopes;
}

bool WSDiscovery200504::TNS__ProbeType::hasValueForScopes() const
{
    return d_ptr->mScopes_nil == false;
}

void WSDiscovery200504::TNS__ProbeType::setAny( const QList< KDSoapValue >& arg_any )
{
    d_ptr->mAny_nil = false;// converter_complextype.cpp:357
    d_ptr->mAny = arg_any;
}

QList< KDSoapValue > WSDiscovery200504::TNS__ProbeType::any() const
{
    return d_ptr->mAny;
}

bool WSDiscovery200504::TNS__ProbeType::hasValueForAny() const
{
    return d_ptr->mAny_nil == false;
}

void WSDiscovery200504::TNS__ProbeType::setAnyAttribute( const KDSoapValue& arg_anyAttribute )
{
    d_ptr->mAnyAttribute_nil = false;// converter_complextype.cpp:357
    d_ptr->mAnyAttribute = arg_anyAttribute;
}

KDSoapValue WSDiscovery200504::TNS__ProbeType::anyAttribute() const
{
    return d_ptr->mAnyAttribute;
}

bool WSDiscovery200504::TNS__ProbeType::hasValueForAnyAttribute() const
{
    return d_ptr->mAnyAttribute_nil == false;
}

KDSoapValue WSDiscovery200504::TNS__ProbeType::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue(valueName, QVariant(), QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"), QString::fromLatin1("ProbeType"));// converter_complextype.cpp:551
    KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:572
    mainValue.setQualified(true);// converter_complextype.cpp:574
    if (!d_ptr->mTypes_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueTypes = d_ptr->mTypes.serialize(QString::fromLatin1("Types"));// elementargumentserializer.cpp:120
        _valueTypes.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueTypes.setQualified(true);
        args.append(_valueTypes);// elementargumentserializer.cpp:132
    }
    if (!d_ptr->mScopes_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueScopes(d_ptr->mScopes.serialize(QString::fromLatin1("Scopes")));// elementargumentserializer.cpp:112
        _valueScopes.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueScopes.setQualified(true);
        args.append(_valueScopes);// elementargumentserializer.cpp:132
    }
    for (int i = 0; i < d_ptr->mAny.count(); ++i) {// converter_complextype.cpp:640
        if (!d_ptr->mAny.at(i).isNull()) {
            args.append(d_ptr->mAny.at(i));// elementargumentserializer.cpp:90
        }
    }
    KDSoapValueList attribs;
    if (!d_ptr->mAnyAttribute.isNull()) {
        attribs.append(d_ptr->mAnyAttribute);// elementargumentserializer.cpp:90
    }
    mainValue.childValues().attributes() += attribs;// converter_complextype.cpp:720
    return mainValue;
}

void WSDiscovery200504::TNS__ProbeType::deserialize( const KDSoapValue& mainValue )
{
    const KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:568
    for (const KDSoapValue& val : std::as_const(args)) {
        const QString _name = val.name();
        if (_name == QLatin1String("Types")) {// converter_complextype.cpp:488
            d_ptr->mTypes.deserialize(val);// elementargumentserializer.cpp:218
            d_ptr->mTypes_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("Scopes")) {// converter_complextype.cpp:488
            d_ptr->mScopes.deserialize(val);// elementargumentserializer.cpp:216
            d_ptr->mScopes_nil = false;// elementargumentserializer.cpp:221
        }
        else {// converter_complextype.cpp:485
            d_ptr->mAny.append(val);
            d_ptr->mAny_nil = false;// elementargumentserializer.cpp:182
        }
    }
    const QList<KDSoapValue> attribs = args.attributes();
    for (const KDSoapValue& val : std::as_const(attribs)) {
        const QString _name = val.name();
        if (_name == QLatin1String("anyAttribute")) {// converter_complextype.cpp:488
            d_ptr->mAnyAttribute = val;// elementargumentserializer.cpp:210
            d_ptr->mAnyAttribute_nil = false;// elementargumentserializer.cpp:221
        }
    }
}

WSDiscovery200504::TNS__ProbeType::TNS__ProbeType()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::TNS__ProbeType::~TNS__ProbeType()
{
}

WSDiscovery200504::TNS__ProbeType::TNS__ProbeType( const WSDiscovery200504::TNS__ProbeType& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::TNS__ProbeType&  WSDiscovery200504::TNS__ProbeType::operator=( const WSDiscovery200504::TNS__ProbeType& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


void WSDiscovery200504::TNS__QNameListType::setEntries( const QList< KDQName >& entries )
{
    mEntries = entries;
}

QList< KDQName > WSDiscovery200504::TNS__QNameListType::entries() const
{
    return mEntries;
}

KDSoapValue WSDiscovery200504::TNS__QNameListType::serialize( const QString& valueName ) const
{
    QString str;
    QXmlStreamNamespaceDeclarations decls;
    for ( int i = 0; i < mEntries.count(); ++i ) {
        if (!str.isEmpty())
            str += QLatin1Char(' ');
        KDSoapValue subValue = mEntries.at(i).toSoapValue(QString(), QString::fromLatin1(""), QString::fromLatin1(""));
        str += subValue.value().toString();
        decls += subValue.namespaceDeclarations();
    }
    KDSoapValue value(valueName, str, QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"), QString::fromLatin1("QNameListType"));
    value.setNamespaceDeclarations(decls);
    return value;
}

void WSDiscovery200504::TNS__QNameListType::deserialize( const KDSoapValue& mainValue )
{
    if (mainValue.value().toString().trimmed().isEmpty()) return;
    const KDSoapValueList list = mainValue.split();
    for (int i = 0; i < list.count(); ++i) {
        mEntries.append(KDQName::fromSoapValue(list.at(i)));
    }
}

WSDiscovery200504::TNS__QNameListType::TNS__QNameListType()
{
}

WSDiscovery200504::TNS__QNameListType::~TNS__QNameListType()
{
}


class WSDiscovery200504::TNS__ResolveMatchType::PrivateDPtr : public QSharedData
{
public:
    PrivateDPtr();

public:
    WSDiscovery200504::WSA__EndpointReferenceType mEndpointReference;
    WSDiscovery200504::TNS__QNameListType mTypes;
    bool mTypes_nil;
    WSDiscovery200504::TNS__ScopesType mScopes;
    bool mScopes_nil;
    WSDiscovery200504::TNS__UriListType mXAddrs;
    unsigned int mMetadataVersion;
    QList< KDSoapValue > mAny;
    bool mAny_nil;
    KDSoapValue mAnyAttribute;
    bool mAnyAttribute_nil;
};

WSDiscovery200504::TNS__ResolveMatchType::PrivateDPtr::PrivateDPtr()
    : mTypes_nil(true), mScopes_nil(true), mMetadataVersion(0), mAny_nil(true), mAnyAttribute_nil(true)
{
}


void WSDiscovery200504::TNS__ResolveMatchType::setEndpointReference( const WSDiscovery200504::WSA__EndpointReferenceType& arg_endpointReference )
{
    d_ptr->mEndpointReference = arg_endpointReference;
}

WSDiscovery200504::WSA__EndpointReferenceType WSDiscovery200504::TNS__ResolveMatchType::endpointReference() const
{
    return d_ptr->mEndpointReference;
}

void WSDiscovery200504::TNS__ResolveMatchType::setTypes( const WSDiscovery200504::TNS__QNameListType& arg_types )
{
    d_ptr->mTypes_nil = false;// converter_complextype.cpp:357
    d_ptr->mTypes = arg_types;
}

WSDiscovery200504::TNS__QNameListType WSDiscovery200504::TNS__ResolveMatchType::types() const
{
    return d_ptr->mTypes;
}

bool WSDiscovery200504::TNS__ResolveMatchType::hasValueForTypes() const
{
    return d_ptr->mTypes_nil == false;
}

void WSDiscovery200504::TNS__ResolveMatchType::setScopes( const WSDiscovery200504::TNS__ScopesType& arg_scopes )
{
    d_ptr->mScopes_nil = false;// converter_complextype.cpp:357
    d_ptr->mScopes = arg_scopes;
}

WSDiscovery200504::TNS__ScopesType WSDiscovery200504::TNS__ResolveMatchType::scopes() const
{
    return d_ptr->mScopes;
}

bool WSDiscovery200504::TNS__ResolveMatchType::hasValueForScopes() const
{
    return d_ptr->mScopes_nil == false;
}

void WSDiscovery200504::TNS__ResolveMatchType::setXAddrs( const WSDiscovery200504::TNS__UriListType& arg_xAddrs )
{
    d_ptr->mXAddrs = arg_xAddrs;
}

WSDiscovery200504::TNS__UriListType WSDiscovery200504::TNS__ResolveMatchType::xAddrs() const
{
    return d_ptr->mXAddrs;
}

void WSDiscovery200504::TNS__ResolveMatchType::setMetadataVersion( unsigned int arg_metadataVersion )
{
    d_ptr->mMetadataVersion = arg_metadataVersion;
}

unsigned int WSDiscovery200504::TNS__ResolveMatchType::metadataVersion() const
{
    return d_ptr->mMetadataVersion;
}

void WSDiscovery200504::TNS__ResolveMatchType::setAny( const QList< KDSoapValue >& arg_any )
{
    d_ptr->mAny_nil = false;// converter_complextype.cpp:357
    d_ptr->mAny = arg_any;
}

QList< KDSoapValue > WSDiscovery200504::TNS__ResolveMatchType::any() const
{
    return d_ptr->mAny;
}

bool WSDiscovery200504::TNS__ResolveMatchType::hasValueForAny() const
{
    return d_ptr->mAny_nil == false;
}

void WSDiscovery200504::TNS__ResolveMatchType::setAnyAttribute( const KDSoapValue& arg_anyAttribute )
{
    d_ptr->mAnyAttribute_nil = false;// converter_complextype.cpp:357
    d_ptr->mAnyAttribute = arg_anyAttribute;
}

KDSoapValue WSDiscovery200504::TNS__ResolveMatchType::anyAttribute() const
{
    return d_ptr->mAnyAttribute;
}

bool WSDiscovery200504::TNS__ResolveMatchType::hasValueForAnyAttribute() const
{
    return d_ptr->mAnyAttribute_nil == false;
}

KDSoapValue WSDiscovery200504::TNS__ResolveMatchType::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue(valueName, QVariant(), QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"), QString::fromLatin1("ResolveMatchType"));// converter_complextype.cpp:551
    KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:572
    mainValue.setQualified(true);// converter_complextype.cpp:574
    KDSoapValue _valueEndpointReference(d_ptr->mEndpointReference.serialize(QString::fromLatin1("EndpointReference")));// elementargumentserializer.cpp:112
    _valueEndpointReference.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"));
    _valueEndpointReference.setQualified(true);
    args.append(_valueEndpointReference);// elementargumentserializer.cpp:132
    if (!d_ptr->mTypes_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueTypes = d_ptr->mTypes.serialize(QString::fromLatin1("Types"));// elementargumentserializer.cpp:120
        _valueTypes.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueTypes.setQualified(true);
        args.append(_valueTypes);// elementargumentserializer.cpp:132
    }
    if (!d_ptr->mScopes_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueScopes(d_ptr->mScopes.serialize(QString::fromLatin1("Scopes")));// elementargumentserializer.cpp:112
        _valueScopes.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueScopes.setQualified(true);
        args.append(_valueScopes);// elementargumentserializer.cpp:132
    }
    KDSoapValue _valueXAddrs = d_ptr->mXAddrs.serialize(QString::fromLatin1("XAddrs"));// elementargumentserializer.cpp:120
    _valueXAddrs.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
    _valueXAddrs.setQualified(true);
    args.append(_valueXAddrs);// elementargumentserializer.cpp:132
    KDSoapValue _valueMetadataVersion = KDSoapValue(QString::fromLatin1("MetadataVersion"), QVariant::fromValue(d_ptr->mMetadataVersion), KDSoapNamespaceManager::xmlSchema2001(), QString::fromLatin1("unsignedInt"));// elementargumentserializer.cpp:117
    _valueMetadataVersion.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
    _valueMetadataVersion.setQualified(true);
    args.append(_valueMetadataVersion);// elementargumentserializer.cpp:132
    for (int i = 0; i < d_ptr->mAny.count(); ++i) {// converter_complextype.cpp:640
        if (!d_ptr->mAny.at(i).isNull()) {
            args.append(d_ptr->mAny.at(i));// elementargumentserializer.cpp:90
        }
    }
    KDSoapValueList attribs;
    if (!d_ptr->mAnyAttribute.isNull()) {
        attribs.append(d_ptr->mAnyAttribute);// elementargumentserializer.cpp:90
    }
    mainValue.childValues().attributes() += attribs;// converter_complextype.cpp:720
    return mainValue;
}

void WSDiscovery200504::TNS__ResolveMatchType::deserialize( const KDSoapValue& mainValue )
{
    const KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:568
    for (const KDSoapValue& val : std::as_const(args)) {
        const QString _name = val.name();
        if (_name == QLatin1String("EndpointReference")) {// converter_complextype.cpp:488
            d_ptr->mEndpointReference.deserialize(val);// elementargumentserializer.cpp:216
        }
        else if (_name == QLatin1String("Types")) {// converter_complextype.cpp:488
            d_ptr->mTypes.deserialize(val);// elementargumentserializer.cpp:218
            d_ptr->mTypes_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("Scopes")) {// converter_complextype.cpp:488
            d_ptr->mScopes.deserialize(val);// elementargumentserializer.cpp:216
            d_ptr->mScopes_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("XAddrs")) {// converter_complextype.cpp:488
            d_ptr->mXAddrs.deserialize(val);// elementargumentserializer.cpp:218
        }
        else if (_name == QLatin1String("MetadataVersion")) {// converter_complextype.cpp:488
            d_ptr->mMetadataVersion = val.value().value<unsigned int>();// elementargumentserializer.cpp:214
        }
        else {// converter_complextype.cpp:485
            d_ptr->mAny.append(val);
            d_ptr->mAny_nil = false;// elementargumentserializer.cpp:182
        }
    }
    const QList<KDSoapValue> attribs = args.attributes();
    for (const KDSoapValue& val : std::as_const(attribs)) {
        const QString _name = val.name();
        if (_name == QLatin1String("anyAttribute")) {// converter_complextype.cpp:488
            d_ptr->mAnyAttribute = val;// elementargumentserializer.cpp:210
            d_ptr->mAnyAttribute_nil = false;// elementargumentserializer.cpp:221
        }
    }
}

WSDiscovery200504::TNS__ResolveMatchType::TNS__ResolveMatchType()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::TNS__ResolveMatchType::~TNS__ResolveMatchType()
{
}

WSDiscovery200504::TNS__ResolveMatchType::TNS__ResolveMatchType( const WSDiscovery200504::TNS__ResolveMatchType& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::TNS__ResolveMatchType&  WSDiscovery200504::TNS__ResolveMatchType::operator=( const WSDiscovery200504::TNS__ResolveMatchType& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


class WSDiscovery200504::TNS__ResolveMatchesType::PrivateDPtr : public QSharedData
{
public:
    PrivateDPtr();

public:
    WSDiscovery200504::TNS__ResolveMatchType mResolveMatch;
    bool mResolveMatch_nil;
    QList< KDSoapValue > mAny;
    bool mAny_nil;
    KDSoapValue mAnyAttribute;
    bool mAnyAttribute_nil;
};

WSDiscovery200504::TNS__ResolveMatchesType::PrivateDPtr::PrivateDPtr()
    : mResolveMatch_nil(true), mAny_nil(true), mAnyAttribute_nil(true)
{
}


void WSDiscovery200504::TNS__ResolveMatchesType::setResolveMatch( const WSDiscovery200504::TNS__ResolveMatchType& arg_resolveMatch )
{
    d_ptr->mResolveMatch_nil = false;// converter_complextype.cpp:357
    d_ptr->mResolveMatch = arg_resolveMatch;
}

WSDiscovery200504::TNS__ResolveMatchType WSDiscovery200504::TNS__ResolveMatchesType::resolveMatch() const
{
    return d_ptr->mResolveMatch;
}

bool WSDiscovery200504::TNS__ResolveMatchesType::hasValueForResolveMatch() const
{
    return d_ptr->mResolveMatch_nil == false;
}

void WSDiscovery200504::TNS__ResolveMatchesType::setAny( const QList< KDSoapValue >& arg_any )
{
    d_ptr->mAny_nil = false;// converter_complextype.cpp:357
    d_ptr->mAny = arg_any;
}

QList< KDSoapValue > WSDiscovery200504::TNS__ResolveMatchesType::any() const
{
    return d_ptr->mAny;
}

bool WSDiscovery200504::TNS__ResolveMatchesType::hasValueForAny() const
{
    return d_ptr->mAny_nil == false;
}

void WSDiscovery200504::TNS__ResolveMatchesType::setAnyAttribute( const KDSoapValue& arg_anyAttribute )
{
    d_ptr->mAnyAttribute_nil = false;// converter_complextype.cpp:357
    d_ptr->mAnyAttribute = arg_anyAttribute;
}

KDSoapValue WSDiscovery200504::TNS__ResolveMatchesType::anyAttribute() const
{
    return d_ptr->mAnyAttribute;
}

bool WSDiscovery200504::TNS__ResolveMatchesType::hasValueForAnyAttribute() const
{
    return d_ptr->mAnyAttribute_nil == false;
}

KDSoapValue WSDiscovery200504::TNS__ResolveMatchesType::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue(valueName, QVariant(), QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"), QString::fromLatin1("ResolveMatchesType"));// converter_complextype.cpp:551
    KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:572
    mainValue.setQualified(true);// converter_complextype.cpp:574
    if (!d_ptr->mResolveMatch_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueResolveMatch(d_ptr->mResolveMatch.serialize(QString::fromLatin1("ResolveMatch")));// elementargumentserializer.cpp:112
        _valueResolveMatch.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        _valueResolveMatch.setQualified(true);
        args.append(_valueResolveMatch);// elementargumentserializer.cpp:132
    }
    for (int i = 0; i < d_ptr->mAny.count(); ++i) {// converter_complextype.cpp:640
        if (!d_ptr->mAny.at(i).isNull()) {
            args.append(d_ptr->mAny.at(i));// elementargumentserializer.cpp:90
        }
    }
    KDSoapValueList attribs;
    if (!d_ptr->mAnyAttribute.isNull()) {
        attribs.append(d_ptr->mAnyAttribute);// elementargumentserializer.cpp:90
    }
    mainValue.childValues().attributes() += attribs;// converter_complextype.cpp:720
    return mainValue;
}

void WSDiscovery200504::TNS__ResolveMatchesType::deserialize( const KDSoapValue& mainValue )
{
    const KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:568
    for (const KDSoapValue& val : std::as_const(args)) {
        const QString _name = val.name();
        if (_name == QLatin1String("ResolveMatch")) {// converter_complextype.cpp:488
            d_ptr->mResolveMatch.deserialize(val);// elementargumentserializer.cpp:216
            d_ptr->mResolveMatch_nil = false;// elementargumentserializer.cpp:221
        }
        else {// converter_complextype.cpp:485
            d_ptr->mAny.append(val);
            d_ptr->mAny_nil = false;// elementargumentserializer.cpp:182
        }
    }
    const QList<KDSoapValue> attribs = args.attributes();
    for (const KDSoapValue& val : std::as_const(attribs)) {
        const QString _name = val.name();
        if (_name == QLatin1String("anyAttribute")) {// converter_complextype.cpp:488
            d_ptr->mAnyAttribute = val;// elementargumentserializer.cpp:210
            d_ptr->mAnyAttribute_nil = false;// elementargumentserializer.cpp:221
        }
    }
}

WSDiscovery200504::TNS__ResolveMatchesType::TNS__ResolveMatchesType()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::TNS__ResolveMatchesType::~TNS__ResolveMatchesType()
{
}

WSDiscovery200504::TNS__ResolveMatchesType::TNS__ResolveMatchesType( const WSDiscovery200504::TNS__ResolveMatchesType& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::TNS__ResolveMatchesType&  WSDiscovery200504::TNS__ResolveMatchesType::operator=( const WSDiscovery200504::TNS__ResolveMatchesType& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


class WSDiscovery200504::TNS__ResolveType::PrivateDPtr : public QSharedData
{
public:
    PrivateDPtr();

public:
    WSDiscovery200504::WSA__EndpointReferenceType mEndpointReference;
    QList< KDSoapValue > mAny;
    bool mAny_nil;
    KDSoapValue mAnyAttribute;
    bool mAnyAttribute_nil;
};

WSDiscovery200504::TNS__ResolveType::PrivateDPtr::PrivateDPtr()
    : mAny_nil(true), mAnyAttribute_nil(true)
{
}


void WSDiscovery200504::TNS__ResolveType::setEndpointReference( const WSDiscovery200504::WSA__EndpointReferenceType& arg_endpointReference )
{
    d_ptr->mEndpointReference = arg_endpointReference;
}

WSDiscovery200504::WSA__EndpointReferenceType WSDiscovery200504::TNS__ResolveType::endpointReference() const
{
    return d_ptr->mEndpointReference;
}

void WSDiscovery200504::TNS__ResolveType::setAny( const QList< KDSoapValue >& arg_any )
{
    d_ptr->mAny_nil = false;// converter_complextype.cpp:357
    d_ptr->mAny = arg_any;
}

QList< KDSoapValue > WSDiscovery200504::TNS__ResolveType::any() const
{
    return d_ptr->mAny;
}

bool WSDiscovery200504::TNS__ResolveType::hasValueForAny() const
{
    return d_ptr->mAny_nil == false;
}

void WSDiscovery200504::TNS__ResolveType::setAnyAttribute( const KDSoapValue& arg_anyAttribute )
{
    d_ptr->mAnyAttribute_nil = false;// converter_complextype.cpp:357
    d_ptr->mAnyAttribute = arg_anyAttribute;
}

KDSoapValue WSDiscovery200504::TNS__ResolveType::anyAttribute() const
{
    return d_ptr->mAnyAttribute;
}

bool WSDiscovery200504::TNS__ResolveType::hasValueForAnyAttribute() const
{
    return d_ptr->mAnyAttribute_nil == false;
}

KDSoapValue WSDiscovery200504::TNS__ResolveType::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue(valueName, QVariant(), QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"), QString::fromLatin1("ResolveType"));// converter_complextype.cpp:551
    KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:572
    mainValue.setQualified(true);// converter_complextype.cpp:574
    KDSoapValue _valueEndpointReference(d_ptr->mEndpointReference.serialize(QString::fromLatin1("EndpointReference")));// elementargumentserializer.cpp:112
    _valueEndpointReference.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"));
    _valueEndpointReference.setQualified(true);
    args.append(_valueEndpointReference);// elementargumentserializer.cpp:132
    for (int i = 0; i < d_ptr->mAny.count(); ++i) {// converter_complextype.cpp:640
        if (!d_ptr->mAny.at(i).isNull()) {
            args.append(d_ptr->mAny.at(i));// elementargumentserializer.cpp:90
        }
    }
    KDSoapValueList attribs;
    if (!d_ptr->mAnyAttribute.isNull()) {
        attribs.append(d_ptr->mAnyAttribute);// elementargumentserializer.cpp:90
    }
    mainValue.childValues().attributes() += attribs;// converter_complextype.cpp:720
    return mainValue;
}

void WSDiscovery200504::TNS__ResolveType::deserialize( const KDSoapValue& mainValue )
{
    const KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:568
    for (const KDSoapValue& val : std::as_const(args)) {
        const QString _name = val.name();
        if (_name == QLatin1String("EndpointReference")) {// converter_complextype.cpp:488
            d_ptr->mEndpointReference.deserialize(val);// elementargumentserializer.cpp:216
        }
        else {// converter_complextype.cpp:485
            d_ptr->mAny.append(val);
            d_ptr->mAny_nil = false;// elementargumentserializer.cpp:182
        }
    }
    const QList<KDSoapValue> attribs = args.attributes();
    for (const KDSoapValue& val : std::as_const(attribs)) {
        const QString _name = val.name();
        if (_name == QLatin1String("anyAttribute")) {// converter_complextype.cpp:488
            d_ptr->mAnyAttribute = val;// elementargumentserializer.cpp:210
            d_ptr->mAnyAttribute_nil = false;// elementargumentserializer.cpp:221
        }
    }
}

WSDiscovery200504::TNS__ResolveType::TNS__ResolveType()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::TNS__ResolveType::~TNS__ResolveType()
{
}

WSDiscovery200504::TNS__ResolveType::TNS__ResolveType( const WSDiscovery200504::TNS__ResolveType& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::TNS__ResolveType&  WSDiscovery200504::TNS__ResolveType::operator=( const WSDiscovery200504::TNS__ResolveType& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


class WSDiscovery200504::TNS__ScopesType::PrivateDPtr : public QSharedData
{
public:
    PrivateDPtr();

public:
    WSDiscovery200504::TNS__UriListType mValue;
    QString mMatchBy;
    bool mMatchBy_nil;
};

WSDiscovery200504::TNS__ScopesType::PrivateDPtr::PrivateDPtr()
    : mMatchBy_nil(true)
{
}


void WSDiscovery200504::TNS__ScopesType::setValue( const WSDiscovery200504::TNS__UriListType& arg_value )
{
    d_ptr->mValue = arg_value;
}

WSDiscovery200504::TNS__UriListType WSDiscovery200504::TNS__ScopesType::value() const
{
    return d_ptr->mValue;
}

WSDiscovery200504::TNS__ScopesType::TNS__ScopesType( const WSDiscovery200504::TNS__UriListType& value )
    : d_ptr(new PrivateDPtr)
{
    d_ptr->mValue = value;
}

WSDiscovery200504::TNS__ScopesType::operator WSDiscovery200504::TNS__UriListType() const
{
    return d_ptr->mValue;
}

void WSDiscovery200504::TNS__ScopesType::setMatchBy( const QString& arg_matchBy )
{
    d_ptr->mMatchBy_nil = false;// converter_complextype.cpp:357
    d_ptr->mMatchBy = arg_matchBy;
}

QString WSDiscovery200504::TNS__ScopesType::matchBy() const
{
    return d_ptr->mMatchBy;
}

bool WSDiscovery200504::TNS__ScopesType::hasValueForMatchBy() const
{
    return d_ptr->mMatchBy_nil == false;
}

KDSoapValue WSDiscovery200504::TNS__ScopesType::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue = d_ptr->mValue.serialize(valueName);// converter_complextype.cpp:542
    mainValue.setType(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"), QString::fromLatin1("ScopesType"));
    KDSoapValueList attribs;
    if (!d_ptr->mMatchBy_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueMatchBy = KDSoapValue(QString::fromLatin1("MatchBy"), QVariant::fromValue(d_ptr->mMatchBy), KDSoapNamespaceManager::xmlSchema2001(), QString::fromLatin1("anyURI"));// elementargumentserializer.cpp:117
        _valueMatchBy.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"));
        attribs.append(_valueMatchBy);// elementargumentserializer.cpp:132
    }
    mainValue.childValues().attributes() += attribs;// converter_complextype.cpp:720
    return mainValue;
}

void WSDiscovery200504::TNS__ScopesType::deserialize( const KDSoapValue& mainValue )
{
    d_ptr->mValue.deserialize(mainValue);// elementargumentserializer.cpp:218
    const KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:568
    Q_UNUSED(mainValue);// converter_complextype.cpp:581
    const QList<KDSoapValue> attribs = args.attributes();
    for (const KDSoapValue& val : std::as_const(attribs)) {
        const QString _name = val.name();
        if (_name == QLatin1String("MatchBy")) {// converter_complextype.cpp:488
            d_ptr->mMatchBy = val.value().value<QString>();// elementargumentserializer.cpp:214
            d_ptr->mMatchBy_nil = false;// elementargumentserializer.cpp:221
        }
    }
}

WSDiscovery200504::TNS__ScopesType::TNS__ScopesType()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::TNS__ScopesType::~TNS__ScopesType()
{
}

WSDiscovery200504::TNS__ScopesType::TNS__ScopesType( const WSDiscovery200504::TNS__ScopesType& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::TNS__ScopesType&  WSDiscovery200504::TNS__ScopesType::operator=( const WSDiscovery200504::TNS__ScopesType& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


void WSDiscovery200504::TNS__UriListType::setEntries( const QStringList& entries )
{
    mEntries = entries;
}

QStringList WSDiscovery200504::TNS__UriListType::entries() const
{
    return mEntries;
}

KDSoapValue WSDiscovery200504::TNS__UriListType::serialize( const QString& valueName ) const
{
    QString str;
    QXmlStreamNamespaceDeclarations decls;
    for ( int i = 0; i < mEntries.count(); ++i ) {
        if (!str.isEmpty())
            str += QLatin1Char(' ');
        str += mEntries.at(i);
    }
    KDSoapValue value(valueName, str, QString::fromLatin1("http://schemas.xmlsoap.org/ws/2005/04/discovery"), QString::fromLatin1("UriListType"));
    value.setNamespaceDeclarations(decls);
    return value;
}

void WSDiscovery200504::TNS__UriListType::deserialize( const KDSoapValue& mainValue )
{
    if (mainValue.value().toString().trimmed().isEmpty()) return;
    const KDSoapValueList list = mainValue.split();
    for (int i = 0; i < list.count(); ++i) {
        mEntries.append(list.at(i).value().toString());
    }
}

WSDiscovery200504::TNS__UriListType::TNS__UriListType()
{
}

WSDiscovery200504::TNS__UriListType::~TNS__UriListType()
{
}


class WSDiscovery200504::WSA__AttributedQName::PrivateDPtr : public QSharedData
{
public:
    KDQName mValue;
};

void WSDiscovery200504::WSA__AttributedQName::setValue( const KDQName& arg_value )
{
    d_ptr->mValue = arg_value;
}

KDQName WSDiscovery200504::WSA__AttributedQName::value() const
{
    return d_ptr->mValue;
}

WSDiscovery200504::WSA__AttributedQName::WSA__AttributedQName( const KDQName& value )
    : d_ptr(new PrivateDPtr)
{
    d_ptr->mValue = value;
}

WSDiscovery200504::WSA__AttributedQName::operator KDQName() const
{
    return d_ptr->mValue;
}

KDSoapValue WSDiscovery200504::WSA__AttributedQName::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue = d_ptr->mValue.toSoapValue(valueName, QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"), QString::fromLatin1("AttributedQName"));// converter_complextype.cpp:540
    return mainValue;
}

void WSDiscovery200504::WSA__AttributedQName::deserialize( const KDSoapValue& mainValue )
{
    d_ptr->mValue = KDQName::fromSoapValue(mainValue);// elementargumentserializer.cpp:214
    Q_UNUSED(mainValue);// converter_complextype.cpp:581
}

WSDiscovery200504::WSA__AttributedQName::WSA__AttributedQName()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::WSA__AttributedQName::~WSA__AttributedQName()
{
}

WSDiscovery200504::WSA__AttributedQName::WSA__AttributedQName( const WSDiscovery200504::WSA__AttributedQName& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::WSA__AttributedQName&  WSDiscovery200504::WSA__AttributedQName::operator=( const WSDiscovery200504::WSA__AttributedQName& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


class WSDiscovery200504::WSA__AttributedURI::PrivateDPtr : public QSharedData
{
public:
    QString mValue;
};

void WSDiscovery200504::WSA__AttributedURI::setValue( const QString& arg_value )
{
    d_ptr->mValue = arg_value;
}

QString WSDiscovery200504::WSA__AttributedURI::value() const
{
    return d_ptr->mValue;
}

WSDiscovery200504::WSA__AttributedURI::WSA__AttributedURI( const QString& value )
    : d_ptr(new PrivateDPtr)
{
    d_ptr->mValue = value;
}

WSDiscovery200504::WSA__AttributedURI::operator QString() const
{
    return d_ptr->mValue;
}

KDSoapValue WSDiscovery200504::WSA__AttributedURI::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue = KDSoapValue(valueName, QVariant::fromValue(d_ptr->mValue), QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"), QString::fromLatin1("AttributedURI"));// converter_complextype.cpp:540
    return mainValue;
}

void WSDiscovery200504::WSA__AttributedURI::deserialize( const KDSoapValue& mainValue )
{
    d_ptr->mValue = mainValue.value().value<QString>();// elementargumentserializer.cpp:214
    Q_UNUSED(mainValue);// converter_complextype.cpp:581
}

WSDiscovery200504::WSA__AttributedURI::WSA__AttributedURI()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::WSA__AttributedURI::~WSA__AttributedURI()
{
}

WSDiscovery200504::WSA__AttributedURI::WSA__AttributedURI( const WSDiscovery200504::WSA__AttributedURI& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::WSA__AttributedURI&  WSDiscovery200504::WSA__AttributedURI::operator=( const WSDiscovery200504::WSA__AttributedURI& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


class WSDiscovery200504::WSA__EndpointReferenceType::PrivateDPtr : public QSharedData
{
public:
    PrivateDPtr();

public:
    WSDiscovery200504::WSA__AttributedURI mAddress;
    WSDiscovery200504::WSA__ReferencePropertiesType mReferenceProperties;
    bool mReferenceProperties_nil;
    WSDiscovery200504::WSA__ReferenceParametersType mReferenceParameters;
    bool mReferenceParameters_nil;
    WSDiscovery200504::WSA__AttributedQName mPortType;
    bool mPortType_nil;
    WSDiscovery200504::WSA__ServiceNameType mServiceName;
    bool mServiceName_nil;
    QList< KDSoapValue > mAny;
    bool mAny_nil;
    KDSoapValue mAnyAttribute;
    bool mAnyAttribute_nil;
};

WSDiscovery200504::WSA__EndpointReferenceType::PrivateDPtr::PrivateDPtr()
    : mReferenceProperties_nil(true), mReferenceParameters_nil(true), mPortType_nil(true), mServiceName_nil(true), mAny_nil(true), mAnyAttribute_nil(true)
{
}


void WSDiscovery200504::WSA__EndpointReferenceType::setAddress( const WSDiscovery200504::WSA__AttributedURI& arg_address )
{
    d_ptr->mAddress = arg_address;
}

WSDiscovery200504::WSA__AttributedURI WSDiscovery200504::WSA__EndpointReferenceType::address() const
{
    return d_ptr->mAddress;
}

void WSDiscovery200504::WSA__EndpointReferenceType::setReferenceProperties( const WSDiscovery200504::WSA__ReferencePropertiesType& arg_referenceProperties )
{
    d_ptr->mReferenceProperties_nil = false;// converter_complextype.cpp:357
    d_ptr->mReferenceProperties = arg_referenceProperties;
}

WSDiscovery200504::WSA__ReferencePropertiesType WSDiscovery200504::WSA__EndpointReferenceType::referenceProperties() const
{
    return d_ptr->mReferenceProperties;
}

bool WSDiscovery200504::WSA__EndpointReferenceType::hasValueForReferenceProperties() const
{
    return d_ptr->mReferenceProperties_nil == false;
}

void WSDiscovery200504::WSA__EndpointReferenceType::setReferenceParameters( const WSDiscovery200504::WSA__ReferenceParametersType& arg_referenceParameters )
{
    d_ptr->mReferenceParameters_nil = false;// converter_complextype.cpp:357
    d_ptr->mReferenceParameters = arg_referenceParameters;
}

WSDiscovery200504::WSA__ReferenceParametersType WSDiscovery200504::WSA__EndpointReferenceType::referenceParameters() const
{
    return d_ptr->mReferenceParameters;
}

bool WSDiscovery200504::WSA__EndpointReferenceType::hasValueForReferenceParameters() const
{
    return d_ptr->mReferenceParameters_nil == false;
}

void WSDiscovery200504::WSA__EndpointReferenceType::setPortType( const WSDiscovery200504::WSA__AttributedQName& arg_portType )
{
    d_ptr->mPortType_nil = false;// converter_complextype.cpp:357
    d_ptr->mPortType = arg_portType;
}

WSDiscovery200504::WSA__AttributedQName WSDiscovery200504::WSA__EndpointReferenceType::portType() const
{
    return d_ptr->mPortType;
}

bool WSDiscovery200504::WSA__EndpointReferenceType::hasValueForPortType() const
{
    return d_ptr->mPortType_nil == false;
}

void WSDiscovery200504::WSA__EndpointReferenceType::setServiceName( const WSDiscovery200504::WSA__ServiceNameType& arg_serviceName )
{
    d_ptr->mServiceName_nil = false;// converter_complextype.cpp:357
    d_ptr->mServiceName = arg_serviceName;
}

WSDiscovery200504::WSA__ServiceNameType WSDiscovery200504::WSA__EndpointReferenceType::serviceName() const
{
    return d_ptr->mServiceName;
}

bool WSDiscovery200504::WSA__EndpointReferenceType::hasValueForServiceName() const
{
    return d_ptr->mServiceName_nil == false;
}

void WSDiscovery200504::WSA__EndpointReferenceType::setAny( const QList< KDSoapValue >& arg_any )
{
    d_ptr->mAny_nil = false;// converter_complextype.cpp:357
    d_ptr->mAny = arg_any;
}

QList< KDSoapValue > WSDiscovery200504::WSA__EndpointReferenceType::any() const
{
    return d_ptr->mAny;
}

bool WSDiscovery200504::WSA__EndpointReferenceType::hasValueForAny() const
{
    return d_ptr->mAny_nil == false;
}

void WSDiscovery200504::WSA__EndpointReferenceType::setAnyAttribute( const KDSoapValue& arg_anyAttribute )
{
    d_ptr->mAnyAttribute_nil = false;// converter_complextype.cpp:357
    d_ptr->mAnyAttribute = arg_anyAttribute;
}

KDSoapValue WSDiscovery200504::WSA__EndpointReferenceType::anyAttribute() const
{
    return d_ptr->mAnyAttribute;
}

bool WSDiscovery200504::WSA__EndpointReferenceType::hasValueForAnyAttribute() const
{
    return d_ptr->mAnyAttribute_nil == false;
}

KDSoapValue WSDiscovery200504::WSA__EndpointReferenceType::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue(valueName, QVariant(), QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"), QString::fromLatin1("EndpointReferenceType"));// converter_complextype.cpp:551
    KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:572
    mainValue.setQualified(true);// converter_complextype.cpp:574
    KDSoapValue _valueAddress(d_ptr->mAddress.serialize(QString::fromLatin1("Address")));// elementargumentserializer.cpp:112
    _valueAddress.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"));
    _valueAddress.setQualified(true);
    args.append(_valueAddress);// elementargumentserializer.cpp:132
    if (!d_ptr->mReferenceProperties_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueReferenceProperties(d_ptr->mReferenceProperties.serialize(QString::fromLatin1("ReferenceProperties")));// elementargumentserializer.cpp:112
        _valueReferenceProperties.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"));
        _valueReferenceProperties.setQualified(true);
        args.append(_valueReferenceProperties);// elementargumentserializer.cpp:132
    }
    if (!d_ptr->mReferenceParameters_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueReferenceParameters(d_ptr->mReferenceParameters.serialize(QString::fromLatin1("ReferenceParameters")));// elementargumentserializer.cpp:112
        _valueReferenceParameters.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"));
        _valueReferenceParameters.setQualified(true);
        args.append(_valueReferenceParameters);// elementargumentserializer.cpp:132
    }
    if (!d_ptr->mPortType_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valuePortType(d_ptr->mPortType.serialize(QString::fromLatin1("PortType")));// elementargumentserializer.cpp:112
        _valuePortType.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"));
        _valuePortType.setQualified(true);
        args.append(_valuePortType);// elementargumentserializer.cpp:132
    }
    if (!d_ptr->mServiceName_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valueServiceName(d_ptr->mServiceName.serialize(QString::fromLatin1("ServiceName")));// elementargumentserializer.cpp:112
        _valueServiceName.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"));
        _valueServiceName.setQualified(true);
        args.append(_valueServiceName);// elementargumentserializer.cpp:132
    }
    for (int i = 0; i < d_ptr->mAny.count(); ++i) {// converter_complextype.cpp:640
        if (!d_ptr->mAny.at(i).isNull()) {
            args.append(d_ptr->mAny.at(i));// elementargumentserializer.cpp:90
        }
    }
    KDSoapValueList attribs;
    if (!d_ptr->mAnyAttribute.isNull()) {
        attribs.append(d_ptr->mAnyAttribute);// elementargumentserializer.cpp:90
    }
    mainValue.childValues().attributes() += attribs;// converter_complextype.cpp:720
    return mainValue;
}

void WSDiscovery200504::WSA__EndpointReferenceType::deserialize( const KDSoapValue& mainValue )
{
    const KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:568
    for (const KDSoapValue& val : std::as_const(args)) {
        const QString _name = val.name();
        if (_name == QLatin1String("Address")) {// converter_complextype.cpp:488
            d_ptr->mAddress.deserialize(val);// elementargumentserializer.cpp:216
        }
        else if (_name == QLatin1String("ReferenceProperties")) {// converter_complextype.cpp:488
            d_ptr->mReferenceProperties.deserialize(val);// elementargumentserializer.cpp:216
            d_ptr->mReferenceProperties_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("ReferenceParameters")) {// converter_complextype.cpp:488
            d_ptr->mReferenceParameters.deserialize(val);// elementargumentserializer.cpp:216
            d_ptr->mReferenceParameters_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("PortType")) {// converter_complextype.cpp:488
            d_ptr->mPortType.deserialize(val);// elementargumentserializer.cpp:216
            d_ptr->mPortType_nil = false;// elementargumentserializer.cpp:221
        }
        else if (_name == QLatin1String("ServiceName")) {// converter_complextype.cpp:488
            d_ptr->mServiceName.deserialize(val);// elementargumentserializer.cpp:216
            d_ptr->mServiceName_nil = false;// elementargumentserializer.cpp:221
        }
        else {// converter_complextype.cpp:485
            d_ptr->mAny.append(val);
            d_ptr->mAny_nil = false;// elementargumentserializer.cpp:182
        }
    }
    const QList<KDSoapValue> attribs = args.attributes();
    for (const KDSoapValue& val : std::as_const(attribs)) {
        const QString _name = val.name();
        if (_name == QLatin1String("anyAttribute")) {// converter_complextype.cpp:488
            d_ptr->mAnyAttribute = val;// elementargumentserializer.cpp:210
            d_ptr->mAnyAttribute_nil = false;// elementargumentserializer.cpp:221
        }
    }
}

WSDiscovery200504::WSA__EndpointReferenceType::WSA__EndpointReferenceType()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::WSA__EndpointReferenceType::~WSA__EndpointReferenceType()
{
}

WSDiscovery200504::WSA__EndpointReferenceType::WSA__EndpointReferenceType( const WSDiscovery200504::WSA__EndpointReferenceType& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::WSA__EndpointReferenceType&  WSDiscovery200504::WSA__EndpointReferenceType::operator=( const WSDiscovery200504::WSA__EndpointReferenceType& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


class WSDiscovery200504::WSA__ReferenceParametersType::PrivateDPtr : public QSharedData
{
public:
    PrivateDPtr();

public:
    QList< KDSoapValue > mAny;
    bool mAny_nil;
};

WSDiscovery200504::WSA__ReferenceParametersType::PrivateDPtr::PrivateDPtr()
    : mAny_nil(true)
{
}


void WSDiscovery200504::WSA__ReferenceParametersType::setAny( const QList< KDSoapValue >& arg_any )
{
    d_ptr->mAny_nil = false;// converter_complextype.cpp:357
    d_ptr->mAny = arg_any;
}

QList< KDSoapValue > WSDiscovery200504::WSA__ReferenceParametersType::any() const
{
    return d_ptr->mAny;
}

bool WSDiscovery200504::WSA__ReferenceParametersType::hasValueForAny() const
{
    return d_ptr->mAny_nil == false;
}

KDSoapValue WSDiscovery200504::WSA__ReferenceParametersType::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue(valueName, QVariant(), QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"), QString::fromLatin1("ReferenceParametersType"));// converter_complextype.cpp:551
    KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:572
    for (int i = 0; i < d_ptr->mAny.count(); ++i) {// converter_complextype.cpp:640
        if (!d_ptr->mAny.at(i).isNull()) {
            args.append(d_ptr->mAny.at(i));// elementargumentserializer.cpp:90
        }
    }
    return mainValue;
}

void WSDiscovery200504::WSA__ReferenceParametersType::deserialize( const KDSoapValue& mainValue )
{
    const KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:568
    for (const KDSoapValue& val : std::as_const(args)) {
        const QString _name = val.name();
        {// converter_complextype.cpp:485
            d_ptr->mAny.append(val);
            d_ptr->mAny_nil = false;// elementargumentserializer.cpp:182
        }
    }
}

WSDiscovery200504::WSA__ReferenceParametersType::WSA__ReferenceParametersType()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::WSA__ReferenceParametersType::~WSA__ReferenceParametersType()
{
}

WSDiscovery200504::WSA__ReferenceParametersType::WSA__ReferenceParametersType( const WSDiscovery200504::WSA__ReferenceParametersType& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::WSA__ReferenceParametersType&  WSDiscovery200504::WSA__ReferenceParametersType::operator=( const WSDiscovery200504::WSA__ReferenceParametersType& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


class WSDiscovery200504::WSA__ReferencePropertiesType::PrivateDPtr : public QSharedData
{
public:
    PrivateDPtr();

public:
    QList< KDSoapValue > mAny;
    bool mAny_nil;
};

WSDiscovery200504::WSA__ReferencePropertiesType::PrivateDPtr::PrivateDPtr()
    : mAny_nil(true)
{
}


void WSDiscovery200504::WSA__ReferencePropertiesType::setAny( const QList< KDSoapValue >& arg_any )
{
    d_ptr->mAny_nil = false;// converter_complextype.cpp:357
    d_ptr->mAny = arg_any;
}

QList< KDSoapValue > WSDiscovery200504::WSA__ReferencePropertiesType::any() const
{
    return d_ptr->mAny;
}

bool WSDiscovery200504::WSA__ReferencePropertiesType::hasValueForAny() const
{
    return d_ptr->mAny_nil == false;
}

KDSoapValue WSDiscovery200504::WSA__ReferencePropertiesType::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue(valueName, QVariant(), QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"), QString::fromLatin1("ReferencePropertiesType"));// converter_complextype.cpp:551
    KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:572
    for (int i = 0; i < d_ptr->mAny.count(); ++i) {// converter_complextype.cpp:640
        if (!d_ptr->mAny.at(i).isNull()) {
            args.append(d_ptr->mAny.at(i));// elementargumentserializer.cpp:90
        }
    }
    return mainValue;
}

void WSDiscovery200504::WSA__ReferencePropertiesType::deserialize( const KDSoapValue& mainValue )
{
    const KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:568
    for (const KDSoapValue& val : std::as_const(args)) {
        const QString _name = val.name();
        {// converter_complextype.cpp:485
            d_ptr->mAny.append(val);
            d_ptr->mAny_nil = false;// elementargumentserializer.cpp:182
        }
    }
}

WSDiscovery200504::WSA__ReferencePropertiesType::WSA__ReferencePropertiesType()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::WSA__ReferencePropertiesType::~WSA__ReferencePropertiesType()
{
}

WSDiscovery200504::WSA__ReferencePropertiesType::WSA__ReferencePropertiesType( const WSDiscovery200504::WSA__ReferencePropertiesType& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::WSA__ReferencePropertiesType&  WSDiscovery200504::WSA__ReferencePropertiesType::operator=( const WSDiscovery200504::WSA__ReferencePropertiesType& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


class WSDiscovery200504::WSA__ServiceNameType::PrivateDPtr : public QSharedData
{
public:
    PrivateDPtr();

public:
    KDQName mValue;
    QString mPortName;
    bool mPortName_nil;
};

WSDiscovery200504::WSA__ServiceNameType::PrivateDPtr::PrivateDPtr()
    : mPortName_nil(true)
{
}


void WSDiscovery200504::WSA__ServiceNameType::setValue( const KDQName& arg_value )
{
    d_ptr->mValue = arg_value;
}

KDQName WSDiscovery200504::WSA__ServiceNameType::value() const
{
    return d_ptr->mValue;
}

WSDiscovery200504::WSA__ServiceNameType::WSA__ServiceNameType( const KDQName& value )
    : d_ptr(new PrivateDPtr)
{
    d_ptr->mValue = value;
}

WSDiscovery200504::WSA__ServiceNameType::operator KDQName() const
{
    return d_ptr->mValue;
}

void WSDiscovery200504::WSA__ServiceNameType::setPortName( const QString& arg_portName )
{
    d_ptr->mPortName_nil = false;// converter_complextype.cpp:357
    d_ptr->mPortName = arg_portName;
}

QString WSDiscovery200504::WSA__ServiceNameType::portName() const
{
    return d_ptr->mPortName;
}

bool WSDiscovery200504::WSA__ServiceNameType::hasValueForPortName() const
{
    return d_ptr->mPortName_nil == false;
}

KDSoapValue WSDiscovery200504::WSA__ServiceNameType::serialize( const QString& valueName ) const
{
    KDSoapValue mainValue = d_ptr->mValue.toSoapValue(valueName, QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"), QString::fromLatin1("ServiceNameType"));// converter_complextype.cpp:540
    KDSoapValueList attribs;
    if (!d_ptr->mPortName_nil) {// elementargumentserializer.cpp:104
        KDSoapValue _valuePortName = KDSoapValue(QString::fromLatin1("PortName"), QVariant::fromValue(d_ptr->mPortName), KDSoapNamespaceManager::xmlSchema2001(), QString::fromLatin1("NCName"));// elementargumentserializer.cpp:117
        _valuePortName.setNamespaceUri(QString::fromLatin1("http://schemas.xmlsoap.org/ws/2004/08/addressing"));
        attribs.append(_valuePortName);// elementargumentserializer.cpp:132
    }
    mainValue.childValues().attributes() += attribs;// converter_complextype.cpp:720
    return mainValue;
}

void WSDiscovery200504::WSA__ServiceNameType::deserialize( const KDSoapValue& mainValue )
{
    d_ptr->mValue = KDQName::fromSoapValue(mainValue);// elementargumentserializer.cpp:214
    const KDSoapValueList& args = mainValue.childValues();// converter_complextype.cpp:568
    Q_UNUSED(mainValue);// converter_complextype.cpp:581
    const QList<KDSoapValue> attribs = args.attributes();
    for (const KDSoapValue& val : std::as_const(attribs)) {
        const QString _name = val.name();
        if (_name == QLatin1String("PortName")) {// converter_complextype.cpp:488
            d_ptr->mPortName = val.value().value<QString>();// elementargumentserializer.cpp:214
            d_ptr->mPortName_nil = false;// elementargumentserializer.cpp:221
        }
    }
}

WSDiscovery200504::WSA__ServiceNameType::WSA__ServiceNameType()
    : d_ptr(new PrivateDPtr)
{
}

WSDiscovery200504::WSA__ServiceNameType::~WSA__ServiceNameType()
{
}

WSDiscovery200504::WSA__ServiceNameType::WSA__ServiceNameType( const WSDiscovery200504::WSA__ServiceNameType& other )
    : d_ptr( other.d_ptr )
{
}

WSDiscovery200504::WSA__ServiceNameType&  WSDiscovery200504::WSA__ServiceNameType::operator=( const WSDiscovery200504::WSA__ServiceNameType& other )
{
    if ( this == &other )
        return *this;

    d_ptr = other.d_ptr;

    return *this;
}


